@@ -84,6 +84,16 @@ cong_command_instance_init (CongCommand *node)
 	node->priv = g_new0(CongCommandDetails,1);
 }
 
+/**
+ * cong_command_construct:
+ * @command:
+ * @doc:
+ * @description:
+ * @consolidation_id:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 CongCommand*
 cong_command_construct (CongCommand *command,
 			CongDocument *doc,
@@ -101,6 +111,15 @@ cong_command_construct (CongCommand *command,
 	return command;
 }
 
+/**
+ * cong_command_private_new:
+ * @doc:
+ * @description:
+ * @consolidation_id:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 CongCommand*
 cong_command_private_new (CongDocument *doc,
 			  const gchar *description,
@@ -112,6 +131,13 @@ cong_command_private_new (CongDocument *doc,
 				       consolidation_id);
 }
 
+/**
+ * cong_command_get_document:
+ * @command:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 CongDocument*
 cong_command_get_document (CongCommand *command)
 {
@@ -120,6 +146,13 @@ cong_command_get_document (CongCommand *command)
 	return PRIVATE(command)->doc;
 }
 
+/**
+ * cong_command_get_description:
+ * @command:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 const gchar*
 cong_command_get_description (CongCommand *command)
 {
@@ -128,6 +161,13 @@ cong_command_get_description (CongCommand *command)
 	return PRIVATE(command)->description;
 }
 
+/**
+ * cong_command_get_consolidation_id:
+ * @command:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 const gchar*
 cong_command_get_consolidation_id (CongCommand *command)
 {
@@ -136,6 +176,12 @@ cong_command_get_consolidation_id (CongCommand *command)
 	return PRIVATE(command)->consolidation_id;
 }
 
+/**
+ * cong_command_undo:
+ * @command:
+ *
+ * TODO: Write me
+ */
 void
 cong_command_undo (CongCommand *command)
 {
@@ -172,6 +218,12 @@ cong_command_undo (CongCommand *command)
 	cong_document_end_edit (doc);
 }
 
+/**
+ * cong_command_redo:
+ * @command:
+ *
+ * TODO: Write me
+ */
 void
 cong_command_redo (CongCommand *command)
 {
@@ -203,6 +255,13 @@ cong_command_redo (CongCommand *command)
 	cong_document_end_edit (doc);
 }
 
+/**
+ * cong_command_merge:
+ * @dst:
+ * @src:
+ *
+ * TODO: Write me
+ */
 void
 cong_command_merge (CongCommand *dst,
 		    CongCommand *src)
@@ -227,6 +286,13 @@ cong_command_has_ever_been_undone (CongCommand *cmd)
 
 
 /* Adding Atomic modifications: */
+/**
+ * cong_command_add_modification:
+ * @cmd:
+ * @modification:
+ *
+ * TODO: Write me
+ */
 void
 cong_command_add_modification (CongCommand *cmd,
 			       CongModification *modification)
@@ -246,7 +312,13 @@ cong_command_add_modification (CongCommand *cmd,
 			      (modification));
 }
 
-
+/**
+ * cong_command_add_node_make_orphan:
+ * @cmd:
+ * @node:
+ *
+ * TODO: Write me
+ */
 void
 cong_command_add_node_make_orphan (CongCommand *cmd,
 				   CongNodePtr node)
@@ -264,6 +336,14 @@ cong_command_add_node_make_orphan (CongCommand *cmd,
 
 }
 
+/**
+ * cong_command_add_node_add_after:
+ * @cmd:
+ * @node:
+ * @older_sibling:
+ *
+ * TODO: Write me
+ */
 void
 cong_command_add_node_add_after (CongCommand *cmd, 
 				 CongNodePtr node, 
@@ -281,7 +361,14 @@ cong_command_add_node_add_after (CongCommand *cmd,
 	g_object_unref (G_OBJECT(modification));
 }
 
-
+/**
+ * cong_command_add_node_add_before:
+ * @cmd:
+ * @node:
+ * @younger_sibling:
+ *
+ * TODO: Write me
+ */
 void 
 cong_command_add_node_add_before (CongCommand *cmd, 
 				  CongNodePtr node, 
@@ -299,6 +386,14 @@ cong_command_add_node_add_before (CongCommand *cmd,
 	g_object_unref (G_OBJECT(modification));
 }
 
+/**
+ * cong_command_add_node_set_parent:
+ * @cmd:
+ * @node:
+ * @adoptive_parent:
+ *
+ * TODO: Write me
+ */
 void 
 cong_command_add_node_set_parent (CongCommand *cmd, 
 				  CongNodePtr node,
@@ -316,6 +411,14 @@ cong_command_add_node_set_parent (CongCommand *cmd,
 	g_object_unref (G_OBJECT(modification));
 }
 
+/**
+ * cong_command_add_node_set_text:
+ * @cmd:
+ * @node:
+ * @new_content:
+ *
+ * TODO: Write me
+ */
 void 
 cong_command_add_node_set_text (CongCommand *cmd, 
 				CongNodePtr node, 
@@ -333,9 +436,20 @@ cong_command_add_node_set_text (CongCommand *cmd,
 	g_object_unref (G_OBJECT(modification));
 }
 
+/**
+ * cong_command_add_node_set_attribute:
+ * @cmd:
+ * @node:
+ * @ns_ptr:
+ * @name:
+ * @value:
+ *
+ * TODO: Write me
+ */
 void 
 cong_command_add_node_set_attribute (CongCommand *cmd, 
 				     CongNodePtr node, 
+				     xmlNs *ns_ptr,
 				     const xmlChar *name, 
 				     const xmlChar *value)
 {
@@ -345,6 +459,7 @@ cong_command_add_node_set_attribute (CongCommand *cmd,
 
 	modification = cong_node_modification_set_attribute_new (cong_command_get_document(cmd),
 								 node,
+								 ns_ptr,
 								 name,
 								 value);
 	cong_command_add_modification (cmd,
@@ -352,9 +467,19 @@ cong_command_add_node_set_attribute (CongCommand *cmd,
 	g_object_unref (G_OBJECT(modification));
 }
 
+/**
+ * cong_command_add_node_remove_attribute:
+ * @cmd:
+ * @node:
+ * @ns_ptr:
+ * @name:
+ *
+ * TODO: Write me
+ */
 void 
 cong_command_add_node_remove_attribute (CongCommand *cmd, 
 					CongNodePtr node, 
+					xmlNs *ns_ptr,
 					const xmlChar *name)
 {
 	CongModification *modification;
@@ -363,6 +488,7 @@ cong_command_add_node_remove_attribute (CongCommand *cmd,
 
 	modification = cong_node_modification_remove_attribute_new (cong_command_get_document(cmd),
 								    node,
+								    ns_ptr,
 								    name);
 
 	cong_command_add_modification (cmd,
@@ -370,6 +496,14 @@ cong_command_add_node_remove_attribute (CongCommand *cmd,
 	g_object_unref (G_OBJECT(modification));
 }
 	
+/**
+ * cong_command_add_selection_change:
+ * @cmd:
+ * @new_logical_start:
+ * @new_logical_end:
+ *
+ * TODO: Write me
+ */
 void 
 cong_command_add_selection_change (CongCommand *cmd,
 				   const CongLocation *new_logical_start,
@@ -389,6 +523,13 @@ cong_command_add_selection_change (CongCommand *cmd,
 	g_object_unref (G_OBJECT(modification));
 }
 
+/**
+ * cong_command_add_cursor_change:
+ * @cmd:
+ * @new_location:
+ *
+ * TODO: Write me
+ */
 void 
 cong_command_add_cursor_change (CongCommand *cmd,
 				const CongLocation *new_location)
@@ -405,6 +546,13 @@ cong_command_add_cursor_change (CongCommand *cmd,
 	g_object_unref (G_OBJECT(modification));
 }
 
+/**
+ * cong_command_add_set_dtd_ptr:
+ * @cmd:
+ * @dtd_ptr:
+ *
+ * TODO: Write me
+ */
 void 
 cong_command_add_set_dtd_ptr (CongCommand *cmd,
 			      xmlDtdPtr dtd_ptr)
@@ -443,6 +591,13 @@ cong_command_add_set_clipboard (CongCommand *cmd,
 }
 #endif
 
+/**
+ * cong_command_add_node_free:
+ * @cmd:
+ * @node:
+ *
+ * This function is not currently implemented
+ */
 void
 cong_command_add_node_free (CongCommand *cmd,
 			    CongNodePtr node)
@@ -451,6 +606,13 @@ cong_command_add_node_free (CongCommand *cmd,
 }
 
 /* Adding Compound modifications: */
+/**
+ * cong_command_add_node_recursive_delete:
+ * @cmd:
+ * @node:
+ *
+ * TODO: Write me
+ */
 void
 cong_command_add_node_recursive_delete (CongCommand *cmd,
 					CongNodePtr node)
@@ -499,6 +661,13 @@ cong_command_add_node_recursive_delete (CongCommand *cmd,
 	cong_document_end_edit (doc);
 }
 
+/**
+ * cong_cursor_get_location:
+ * @cursor:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 const CongLocation*
 cong_cursor_get_location (const CongCursor *cursor)
 {
@@ -507,6 +676,14 @@ cong_cursor_get_location (const CongCursor *cursor)
 	return &cursor->location;
 }
 
+/**
+ * cong_command_for_each_location:
+ * @cmd:
+ * @callback:
+ * @user_data:
+ *
+ * TODO: Write me
+ */
 void
 cong_command_for_each_location (CongCommand *cmd, 
 				CongUpdateLocationCallback callback, 
@@ -632,6 +809,13 @@ recursive_node_deletion_update_location_callback (CongDocument *doc,
 	return FALSE;
 }
 
+/**
+ * cong_command_add_delete_range:
+ * @cmd:
+ * @range:
+ *
+ * TODO: Write me
+ */
 void 
 cong_command_add_delete_range (CongCommand *cmd,
 			       CongRange *range)
@@ -675,7 +859,7 @@ cong_command_add_delete_range (CongCommand *cmd,
 
 		/* Split, first */
 
-		if (loc0.byte_offset && cong_node_type(loc0.node) == CONG_NODE_TYPE_TEXT)
+		if (loc0.byte_offset && cong_node_type_is_textual (cong_node_type(loc0.node)))
 		{
 			prev_node = cong_command_add_xml_frag_data_nice_split2 (cmd, &loc0);
 			g_assert(prev_node);
@@ -703,7 +887,7 @@ cong_command_add_delete_range (CongCommand *cmd,
 
 		/* Split, last */
 
-		if (loc1.byte_offset && cong_node_type(loc1.node) == CONG_NODE_TYPE_TEXT)
+		if (loc1.byte_offset && cong_node_type_is_textual (cong_node_type(loc1.node)))
 		{
 			loc1.node = cong_command_add_xml_frag_data_nice_split2(cmd, &loc1);
 		}
@@ -776,6 +960,12 @@ cong_command_add_delete_range (CongCommand *cmd,
 	cong_document_end_edit (doc);
 }
 
+/**
+ * cong_command_add_delete_selection:
+ * @cmd:
+ *
+ * TODO: Write me
+ */
 void 
 cong_command_add_delete_selection (CongCommand *cmd)
 {
@@ -801,6 +991,13 @@ cong_command_add_delete_selection (CongCommand *cmd)
 	cong_document_end_edit (doc);
 }
 
+/**
+ * cong_command_add_insert_text_at_cursor:
+ * @cmd:
+ * @string:
+ *
+ * TODO: Write me
+ */
 void 
 cong_command_add_insert_text_at_cursor (CongCommand *cmd, 
 					const gchar *string)
@@ -856,6 +1053,12 @@ cong_command_add_insert_text_at_cursor (CongCommand *cmd,
 	cong_document_end_edit (doc);
 }
 
+/**
+ * cong_command_add_nullify_cursor:
+ * @cmd:
+ *
+ * TODO: Write me
+ */
 void 
 cong_command_add_nullify_cursor (CongCommand *cmd)
 {
@@ -872,6 +1075,12 @@ cong_command_add_nullify_cursor (CongCommand *cmd)
 					&new_logical_loc);
 }
 
+/**
+ * cong_command_add_nullify_selection:
+ * @cmd:
+ *
+ * TODO: Write me
+ */
 void 
 cong_command_add_nullify_selection (CongCommand *cmd)
 {
@@ -891,6 +1100,14 @@ cong_command_add_nullify_selection (CongCommand *cmd)
 					   &new_logical_loc);	
 }
 
+/**
+ * cong_command_add_xml_frag_data_nice_split2:
+ * @cmd:
+ * @loc:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 CongNodePtr
 cong_command_add_xml_frag_data_nice_split2  (CongCommand *cmd, 
 					     const CongLocation *loc)
@@ -898,11 +1115,14 @@ cong_command_add_xml_frag_data_nice_split2  (CongCommand *cmd,
 	CongDocument *doc;
 	CongNodePtr d = NULL;
 	int len1, len2;
+	CongNodeType node_type;
 
 	g_return_val_if_fail (IS_CONG_COMMAND (cmd), NULL);
 	g_return_val_if_fail (loc, NULL);
 	g_return_val_if_fail (cong_location_exists(loc), NULL);
-	g_return_val_if_fail ((cong_location_node_type(loc) == CONG_NODE_TYPE_TEXT), NULL);
+	g_return_val_if_fail (cong_node_type_is_textual (cong_location_node_type(loc)), NULL);
+
+	node_type = cong_location_node_type(loc);
 	
 	CONG_NODE_SELF_TEST(loc->node);
 
@@ -917,9 +1137,9 @@ cong_command_add_xml_frag_data_nice_split2  (CongCommand *cmd,
 	g_assert (len2>=0);
 
 	if (len1==0 && len2==0) {
-		d = cong_node_new_text("", doc);
+		d = cong_node_new_textual (node_type, "", doc);
 	} else if (len1==0) {
-		d = cong_node_new_text("", doc);
+		d = cong_node_new_textual (node_type, "", doc);
 
 		/* Link it in */
 		cong_command_add_node_add_before (cmd, 
@@ -928,12 +1148,12 @@ cong_command_add_xml_frag_data_nice_split2  (CongCommand *cmd,
 		return(d);
 
 	} else if (len2==0) {
-		d = cong_node_new_text("", doc);
+		d = cong_node_new_textual (node_type, "", doc);
 	} else {
 		xmlChar* new_text = g_strndup(loc->node->content, len1); /* FIXME:  char type conversion? */
 
 		/* Make split representation */
-		d = cong_node_new_text_len(xml_frag_data_nice(loc->node) + len1, len2, doc); /* FIXME: check char ptr arithmetic; UTF8? */
+		d = cong_node_new_textual_len (node_type, xml_frag_data_nice(loc->node) + len1, len2, doc); /* FIXME: check char ptr arithmetic; UTF8? */
 
 		/* Shrink original node */
 		cong_command_add_node_set_text(cmd, 
@@ -964,6 +1184,7 @@ merge_text_update_location_callback (CongDocument *doc,
 
 	g_assert (affected_node);
 	g_assert (affected_node->prev);
+
 	g_assert (cong_node_type (affected_node)==CONG_NODE_TYPE_TEXT);
 	g_assert (cong_node_type (affected_node->prev)==CONG_NODE_TYPE_TEXT);
 
@@ -1017,7 +1238,12 @@ merge_adjacent_text_callback (CongDocument *doc,
 	return FALSE;
 }
 
-
+/**
+ * cong_command_add_merge_adjacent_text_nodes:
+ * @cmd:
+ *
+ * TODO: Write me
+ */
 void
 cong_command_add_merge_adjacent_text_nodes (CongCommand *cmd)
 {
@@ -1034,6 +1260,13 @@ cong_command_add_merge_adjacent_text_nodes (CongCommand *cmd)
 	cong_document_end_edit (doc);
 }
 
+/**
+ * cong_command_add_merge_adjacent_text_children_of_node:
+ * @cmd:
+ * @node:
+ *
+ * TODO: Write me
+ */
 void
 cong_command_add_merge_adjacent_text_children_of_node (CongCommand *cmd, 
 						       CongNodePtr node)
@@ -1051,6 +1284,14 @@ cong_command_add_merge_adjacent_text_children_of_node (CongCommand *cmd,
 	cong_document_end_edit (doc);
 }
 
+/**
+ * cong_command_can_add_reparent_selection:
+ * @cmd:
+ * @new_parent:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 gboolean
 cong_command_can_add_reparent_selection (CongCommand *cmd,
 					 CongNodePtr new_parent)
@@ -1071,9 +1312,17 @@ cong_command_can_add_reparent_selection (CongCommand *cmd,
 	return TRUE;
 }
 
+/**
+ * cong_command_add_reparent_selection:
+ * @cmd:
+ * @node:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 CongNodePtr
 cong_command_add_reparent_selection (CongCommand *cmd, 
-				     CongNodePtr new_parent)
+				     CongNodePtr node)
 {
 	CongDocument *doc;
 	CongSelection *selection;
@@ -1085,7 +1334,7 @@ cong_command_add_reparent_selection (CongCommand *cmd,
 	CongLocation new_selection_end;
 
 	g_return_val_if_fail (IS_CONG_COMMAND(cmd), NULL);
-	g_return_val_if_fail (new_parent, NULL);
+	g_return_val_if_fail (node, NULL);
 
 	doc = cong_command_get_document (cmd);
 	selection = cong_document_get_selection (doc);
@@ -1104,7 +1353,7 @@ cong_command_add_reparent_selection (CongCommand *cmd,
 	cong_location_copy (&new_selection_start, ordered_start);
 	cong_location_copy (&new_selection_end, ordered_end);
 
-	CONG_NODE_SELF_TEST(new_parent);
+	CONG_NODE_SELF_TEST(node);
 
 	/* --- Processing for multiple nodes --- */
 	if (loc0.node != loc1.node)
@@ -1116,7 +1365,7 @@ cong_command_add_reparent_selection (CongCommand *cmd,
 	
 		/* Split, first */
 
-		if (loc0.byte_offset && cong_node_type(loc0.node) == CONG_NODE_TYPE_TEXT)
+		if (loc0.byte_offset && cong_node_type_is_textual (cong_node_type(loc0.node)))
 		{
 			prev_node = cong_command_add_xml_frag_data_nice_split2(cmd, &loc0);
 			g_assert(prev_node);
@@ -1132,10 +1381,10 @@ cong_command_add_reparent_selection (CongCommand *cmd,
 
 		/* Position new_parent within the tree: */
 		if (prev_node) {
-			cong_command_add_node_add_after(cmd, new_parent, prev_node);
+			cong_command_add_node_add_after(cmd, node, prev_node);
 			CONG_NODE_SELF_TEST(prev_node);
 		} else {
-			cong_command_add_node_set_parent(cmd, new_parent, loc0.node->parent);
+			cong_command_add_node_set_parent(cmd, node, loc0.node->parent);
 		}
 
 		/* Reparent, first & middle */
@@ -1143,17 +1392,17 @@ cong_command_add_reparent_selection (CongCommand *cmd,
 			iter_next = iter->next;
 
 			CONG_NODE_SELF_TEST(iter);
-			CONG_NODE_SELF_TEST(new_parent);
+			CONG_NODE_SELF_TEST(node);
 
-			cong_command_add_node_set_parent(cmd, iter, new_parent);			
+			cong_command_add_node_set_parent(cmd, iter, node);			
 
 			CONG_NODE_SELF_TEST(iter);
-			CONG_NODE_SELF_TEST(new_parent);
+			CONG_NODE_SELF_TEST(node);
 		}
 
 		/* Split, last */
 
-		if (loc1.byte_offset && cong_node_type(loc1.node) == CONG_NODE_TYPE_TEXT)
+		if (loc1.byte_offset && cong_node_type_is_textual (cong_node_type(loc1.node)))
 		{
 			loc1.node = cong_command_add_xml_frag_data_nice_split2(cmd, &loc1);
 			new_selection_end.node = loc1.node->next;
@@ -1162,7 +1411,7 @@ cong_command_add_reparent_selection (CongCommand *cmd,
 		new_selection_end.byte_offset = 0;
 
 		/* Reparent, last */
-		cong_command_add_node_set_parent(cmd, loc1.node, new_parent);
+		cong_command_add_node_set_parent(cmd, loc1.node, node);
 
 		cong_command_add_selection_change (cmd,
 						   &new_selection_start,
@@ -1179,7 +1428,7 @@ cong_command_add_reparent_selection (CongCommand *cmd,
 	{
 		cong_document_begin_edit(doc);
 
-		if (cong_node_type(loc0.node) == CONG_NODE_TYPE_TEXT)
+		if (cong_node_type_is_textual (cong_node_type(loc0.node)))
 		{
 			if (loc0.byte_offset == loc1.byte_offset) {
 				cong_document_end_edit(doc);
@@ -1195,12 +1444,12 @@ cong_command_add_reparent_selection (CongCommand *cmd,
 		
 		/* Position new_parent where the selection was: */
 		if (loc0.node->prev) {
-			cong_command_add_node_add_after(cmd, new_parent, loc0.node->prev);
+			cong_command_add_node_add_after(cmd, node, loc0.node->prev);
 		} else {
-			cong_command_add_node_set_parent(cmd, new_parent, loc0.node->parent);
+			cong_command_add_node_set_parent(cmd, node, loc0.node->parent);
 		}
 		/* Move the selection below new_parent: */
-		cong_command_add_node_set_parent(cmd, cong_selection_get_ordered_start (selection)->node, new_parent);
+		cong_command_add_node_set_parent(cmd, cong_selection_get_ordered_start (selection)->node, node);
 
 		cong_command_add_selection_change (cmd,
 						   &new_selection_start,
@@ -1209,7 +1458,7 @@ cong_command_add_reparent_selection (CongCommand *cmd,
 		cong_document_end_edit(doc);
 
 		/* Return node before new_parent's new position (I think): */
-		return new_parent->prev;
+		return node->prev;
 	}
 }
 
@@ -1251,6 +1500,16 @@ split3_location_callback (CongDocument *doc,
 }
 
 /* Splits a data node in 3 and returns pointer to the middle one */
+/**
+ * cong_command_add_node_split3:
+ * @cmd:
+ * @node:
+ * @c0:
+ * @c1:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 CongNodePtr
 cong_command_add_node_split3 (CongCommand *cmd, 
 			      CongNodePtr node, 
@@ -1260,9 +1519,12 @@ cong_command_add_node_split3 (CongCommand *cmd,
 	CongDocument *doc;
 	CongNodePtr d1, d2, d3;
 	int len1, len2, len3;
+	CongNodeType node_type;
 
 	g_return_val_if_fail (IS_CONG_COMMAND (cmd), NULL);
-	g_return_val_if_fail (cong_node_type(node) == CONG_NODE_TYPE_TEXT, NULL);
+	g_return_val_if_fail (cong_node_type_is_textual (cong_node_type(node)), NULL);
+
+	node_type = cong_node_type (node);
 
 	CONG_NODE_SELF_TEST(node);
 
@@ -1277,9 +1539,9 @@ cong_command_add_node_split3 (CongCommand *cmd,
 	len3 = cong_node_get_length(node) - c1;
 
 	/* Make split representation */
-	d1 = cong_node_new_text_len(xml_frag_data_nice(node), len1, doc); /* FIXME:  audit the char types here, and the char pointer arithmetic. UTF8? */
-	d2 = cong_node_new_text_len(xml_frag_data_nice(node) + len1, len2, doc);
-	d3 = cong_node_new_text_len(xml_frag_data_nice(node) + len1 + len2, len3, doc);
+	d1 = cong_node_new_textual_len (node_type, xml_frag_data_nice(node), len1, doc); /* FIXME:  audit the char types here, and the char pointer arithmetic. UTF8? */
+	d2 = cong_node_new_textual_len (node_type, xml_frag_data_nice(node) + len1, len2, doc);
+	d3 = cong_node_new_textual_len (node_type, xml_frag_data_nice(node) + len1 + len2, len3, doc);
 
 	cong_document_begin_edit(doc);
 
@@ -1315,6 +1577,13 @@ cong_command_add_node_split3 (CongCommand *cmd,
 	return(d2);
 }
 
+/**
+ * cong_command_add_remove_tag:
+ * @cmd:
+ * @node:
+ *
+ * TODO: Write me
+ */
 void 
 cong_command_add_remove_tag (CongCommand *cmd,
 			     CongNodePtr node)
@@ -1344,6 +1613,13 @@ cong_command_add_remove_tag (CongCommand *cmd,
 	cong_document_end_edit (doc);
 }
 
+/**
+ * cong_command_add_set_cursor_to_first_text_descendant:
+ * @cmd:
+ * @node:
+ *
+ * TODO: Write me
+ */
 void
 cong_command_add_set_cursor_to_first_text_descendant (CongCommand *cmd,
 						      CongNodePtr node)
@@ -1373,6 +1649,15 @@ cong_command_add_set_cursor_to_first_text_descendant (CongCommand *cmd,
 	}
 }
 
+/**
+ * cong_command_add_set_external_dtd:
+ * @cmd:
+ * @root_element:
+ * @public_id:
+ * @system_id:
+ *
+ * TODO: Write me
+ */
 void
 cong_command_add_set_external_dtd (CongCommand *cmd,
 				   const gchar* root_element,
