@@ -32,6 +32,7 @@
 #include "cong-selection.h"
 #include "cong-ui-hooks.h"
 
+#undef PRIVATE
 #define PRIVATE(x) ((x)->private)
 
 #define DEBUG_REQUISITIONS 0
@@ -52,6 +53,8 @@ enum {
 
 	STATE_CHANGED,
 
+	WIDTH_CHANGED,
+
 	LAST_SIGNAL
 };
 
@@ -199,6 +202,14 @@ cong_editor_area_class_init (CongEditorAreaClass *klass)
 					       g_cclosure_marshal_VOID__VOID,
 					       G_TYPE_NONE,
 					       0);
+	signals[WIDTH_CHANGED] = g_signal_new ("width_changed",
+					       CONG_EDITOR_AREA_TYPE,
+					       G_SIGNAL_RUN_LAST,
+					       G_STRUCT_OFFSET(CongEditorAreaClass, width_changed),
+					       NULL, NULL,
+					       g_cclosure_marshal_VOID__VOID,
+					       G_TYPE_NONE,
+					       0);
 }
 
 static void
@@ -420,6 +431,10 @@ cong_editor_area_get_requisition (CongEditorArea *area,
 
 	g_return_val_if_fail (IS_CONG_EDITOR_AREA(area), 0);
 
+	if (PRIVATE(area)->is_hidden) {
+	        return 0;
+	}
+
 	cache = &PRIVATE(area)->requisition_cache[orientation];
 
 	/* If not up-to-date, call fn to regenerate cache: */
@@ -512,6 +527,23 @@ cong_editor_area_get_cached_requisition (CongEditorArea *area,
 	return cache->last_calculated_requisition;
 }
 
+gint
+cong_editor_area_get_allocation_width (CongEditorArea *area)
+{
+	g_return_val_if_fail (IS_CONG_EDITOR_AREA(area), 0);
+
+	return PRIVATE(area)->window_area.width;
+}
+
+gint
+cong_editor_area_get_allocation_height (CongEditorArea *area)
+{
+	g_return_val_if_fail (IS_CONG_EDITOR_AREA(area), 0);
+
+	return PRIVATE(area)->window_area.height;
+}
+
+
 #if 0
 void 
 cong_editor_area_set_requisition (CongEditorArea *area,
@@ -759,15 +791,11 @@ cong_editor_area_calc_requisition (CongEditorArea *editor_area,
 				   int width_hint)
 {
 	g_return_val_if_fail (editor_area, 0);
-	
-	if (PRIVATE(editor_area)->is_hidden) {
-	        return 0;
-        } else {
-		return CONG_EEL_CALL_METHOD_WITH_RETURN_VALUE (CONG_EDITOR_AREA_CLASS,
+
+	return CONG_EEL_CALL_METHOD_WITH_RETURN_VALUE (CONG_EDITOR_AREA_CLASS,
 						       editor_area,
 						       calc_requisition, 
 						       (editor_area, orientation, width_hint));
-        }						       
 }
 
 /**
@@ -788,8 +816,11 @@ cong_editor_area_set_allocation (CongEditorArea *editor_area,
 				 gint height)
 {
 	gboolean has_changed = TRUE;
+	gint old_width;
 
-	g_return_if_fail (editor_area);
+	g_return_if_fail (IS_CONG_EDITOR_AREA (editor_area));
+
+	old_width = PRIVATE(editor_area)->window_area.width;
 
 	if (PRIVATE(editor_area)->window_area.x == x) {
 		if (PRIVATE(editor_area)->window_area.y == y) {
@@ -817,6 +848,11 @@ cong_editor_area_set_allocation (CongEditorArea *editor_area,
 		PRIVATE(editor_area)->window_area.height = height;
 	}
 
+	if (old_width!=width) {
+		g_signal_emit (G_OBJECT(editor_area),
+			       signals[WIDTH_CHANGED], 0);
+	}
+
 	if (has_changed || PRIVATE(editor_area)->needs_recursive_allocation) {
 
 		PRIVATE(editor_area)->needs_recursive_allocation = FALSE;
