@@ -29,36 +29,12 @@
 
 #include "cong-editor-area-bin.h"
 
-#define PRIVATE(x) ((x)->private)
-
-struct CongEditorNodeDocumentDetails
-{
-	int dummy;
-};
-
-static CongEditorArea*
-generate_block_area (CongEditorNode *editor_node);
-
 /* Exported function definitions: */
-GNOME_CLASS_BOILERPLATE(CongEditorNodeDocument, 
-			cong_editor_node_document,
-			CongEditorNode,
-			CONG_EDITOR_NODE_TYPE );
-
-static void
-cong_editor_node_document_class_init (CongEditorNodeDocumentClass *klass)
-{
-
-	CongEditorNodeClass *node_klass = CONG_EDITOR_NODE_CLASS(klass);
-
-	node_klass->generate_block_area = generate_block_area;
-}
-
-static void
-cong_editor_node_document_instance_init (CongEditorNodeDocument *node_document)
-{
-	node_document->private = g_new0(CongEditorNodeDocumentDetails,1);
-}
+CONG_EDITOR_NODE_DEFINE_SUBCLASS(Document, 
+				 document,
+				 CONG_EDITOR_NODE_DOCUMENT,
+				 int dummy;
+				 )
 
 /**
  * cong_editor_node_document_construct:
@@ -80,34 +56,19 @@ cong_editor_node_document_construct (CongEditorNodeDocument *editor_node_documen
 	return editor_node_document;
 }
 
-/**
- * cong_editor_node_document_new:
- * @widget:
- * @traversal_node:
- *
- * TODO: Write me
- * Returns:
- */
-CongEditorNode*
-cong_editor_node_document_new (CongEditorWidget3 *widget,
-			       CongTraversalNode *traversal_node)
-{
-#if DEBUG_EDITOR_NODE_LIFETIMES
-	g_message("cong_editor_node_document_new()");
-#endif
-	return CONG_EDITOR_NODE( cong_editor_node_document_construct (g_object_new (CONG_EDITOR_NODE_DOCUMENT_TYPE, NULL),
-								      widget,
-								      traversal_node)
-				 );
-}
+CONG_EDITOR_NODE_IMPLEMENT_EMPTY_DISPOSE(document)
 
-/**
- * generate_block_area:
- * @editor_node:
- *
- * TODO: Write me
- * Returns:
- */
+#if 1
+static void 
+document_create_areas (CongEditorNode *editor_node,
+		       const CongAreaCreationInfo *creation_info)
+{
+	cong_editor_node_empty_create_area (editor_node,
+					    creation_info,
+					    TRUE);
+}
+CONG_EDITOR_NODE_DEFINE_EMPTY_AREA_REGENERATION_HOOK(document)
+#else
 static CongEditorArea*
 generate_block_area (CongEditorNode *editor_node)
 {
@@ -119,3 +80,4 @@ generate_block_area (CongEditorNode *editor_node)
 
 	return new_area;
 }
+#endif
