@@ -31,6 +31,7 @@
 #include "cong-editor-area-structural-tag.h"
 #include "cong-dispspec-element.h"
 
+#undef PRIVATE
 #define PRIVATE(x) ((x)->private)
 
 struct CongEditorNodeElementStructuralDetails
@@ -38,27 +39,23 @@ struct CongEditorNodeElementStructuralDetails
 	int dummy;
 };
 
-static CongEditorArea*
-generate_block_area (CongEditorNode *editor_node);
+CONG_EDITOR_NODE_DECLARE_HOOKS(structural)
 
 /* Declarations of the CongEditorArea event handlers: */
 
 /* Exported function definitions: */
-GNOME_CLASS_BOILERPLATE(CongEditorNodeElementStructural, 
-			cong_editor_node_element_structural,
-			CongEditorNodeElement,
-			CONG_EDITOR_NODE_ELEMENT_TYPE );
+G_DEFINE_TYPE(CongEditorNodeElementStructural, 
+	      cong_editor_node_element_structural,
+	      CONG_EDITOR_NODE_ELEMENT_TYPE );
 
 static void
 cong_editor_node_element_structural_class_init (CongEditorNodeElementStructuralClass *klass)
 {
-	CongEditorNodeClass *node_klass = CONG_EDITOR_NODE_CLASS(klass);
-
-	node_klass->generate_block_area = generate_block_area;
+	CONG_EDITOR_NODE_CONNECT_HOOKS(structural)
 }
 
 static void
-cong_editor_node_element_structural_instance_init (CongEditorNodeElementStructural *node_element_structural)
+cong_editor_node_element_structural_init (CongEditorNodeElementStructural *node_element_structural)
 {
 	node_element_structural->private = g_new0(CongEditorNodeElementStructuralDetails,1);
 }
@@ -106,6 +103,44 @@ cong_editor_node_element_structural_new (CongEditorWidget3* widget,
 				  traversal_node));
 }
 
+#if 1
+static void 
+structural_create_areas (CongEditorNode *editor_node,
+			 const CongAreaCreationInfo *creation_info)
+{
+	CongEditorArea *block_area;
+	CongDispspecElement *ds_element;
+	GdkPixbuf *pixbuf;
+	gchar *title_text;
+
+	g_return_if_fail (editor_node);
+
+	ds_element = cong_editor_node_element_get_dispspec_element (CONG_EDITOR_NODE_ELEMENT (editor_node));
+	pixbuf = cong_dispspec_element_get_icon (ds_element);
+	title_text = cong_dispspec_element_get_section_header_text (ds_element,
+								    cong_editor_node_get_node (editor_node));
+
+	block_area = cong_editor_area_structural_tag_new (cong_editor_node_get_widget (editor_node),
+							  ds_element,
+							  pixbuf,
+							  title_text);
+	if (pixbuf) {
+		g_object_unref (G_OBJECT(pixbuf));
+	}
+	g_free (title_text);
+
+	cong_editor_area_connect_node_signals (block_area,
+					       editor_node);
+
+	cong_editor_node_create_block_area (editor_node,
+					    creation_info,
+					    block_area,
+					    TRUE);
+}
+
+CONG_EDITOR_NODE_DEFINE_BLOCK_AREA_REGENERATION_HOOK(structural)
+
+#else
 static CongEditorArea*
 generate_block_area (CongEditorNode *editor_node)
 {
@@ -156,5 +191,6 @@ generate_block_area (CongEditorNode *editor_node)
 
 	return inner_area;
 }
+#endif
 
 /* Definitions of the CongEditorArea event handlers: */
