@@ -121,6 +121,10 @@ gboolean plugin_xsl_plugin_configure(CongPlugin *plugin);
 gboolean plugin_save_dispspec_plugin_register(CongPlugin *plugin);
 gboolean plugin_save_dispspec_plugin_configure(CongPlugin *plugin);
 
+/* plugin-table.c */
+gboolean plugin_table_plugin_register(CongPlugin *plugin);
+gboolean plugin_table_plugin_configure(CongPlugin *plugin);
+
 /* plugin-templates.c */
 gboolean plugin_templates_plugin_register(CongPlugin *plugin);
 gboolean plugin_templates_plugin_configure(CongPlugin *plugin);
