@@ -11,10 +11,17 @@
 #include "cong-command.h"
 
  
+/**
+ * cong_location_is_valid:
+ * @loc:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 gboolean
 cong_location_is_valid(const CongLocation *loc)
 {
-	enum CongNodeType type;
+	CongNodeType type;
 	
 	g_return_val_if_fail(loc != NULL, FALSE);
 
@@ -28,6 +35,7 @@ cong_location_is_valid(const CongLocation *loc)
 			return (loc->byte_offset==CONG_LOCATION_BYTE_OFFSET_MEANINGLESS);
 	
 		case CONG_NODE_TYPE_TEXT:
+		case CONG_NODE_TYPE_CDATA_SECTION:
 		case CONG_NODE_TYPE_COMMENT:
 			{	   
 				/* Test that the byte offset is at the start of a character, in range, etc... */
@@ -49,6 +57,12 @@ cong_location_is_valid(const CongLocation *loc)
 	}
 }
 
+/**
+ * cong_location_nullify:
+ * @loc:
+ *
+ * TODO: Write me
+ */
 void
 cong_location_nullify(CongLocation *loc)
 {
@@ -58,6 +72,13 @@ cong_location_nullify(CongLocation *loc)
 	loc->byte_offset=CONG_LOCATION_BYTE_OFFSET_NULL_NODE; /* for good measure */
 }
 
+/**
+ * cong_location_set_to_start_of_node:
+ * @loc:
+ * @node:
+ *
+ * TODO: Write me
+ */
 void
 cong_location_set_to_start_of_node(CongLocation *loc, CongNodePtr node)
 {
@@ -72,12 +93,20 @@ cong_location_set_to_start_of_node(CongLocation *loc, CongNodePtr node)
 			break;
 			
 		case CONG_NODE_TYPE_TEXT:
+		case CONG_NODE_TYPE_CDATA_SECTION:
 		case CONG_NODE_TYPE_COMMENT:
 			loc->byte_offset = 0;
 			break;
 	}
 }
 
+/**
+ * cong_location_set_to_end_of_node:
+ * @loc:
+ * @node:
+ *
+ * TODO: Write me
+ */
 void
 cong_location_set_to_end_of_node(CongLocation *loc, CongNodePtr node)
 {
@@ -92,12 +121,21 @@ cong_location_set_to_end_of_node(CongLocation *loc, CongNodePtr node)
 			break;
 			
 		case CONG_NODE_TYPE_TEXT:
+		case CONG_NODE_TYPE_CDATA_SECTION:
 		case CONG_NODE_TYPE_COMMENT:
 			loc->byte_offset = strlen (node->content);
 			break;
 	}
 }
 
+/**
+ * cong_location_set_node_and_byte_offset:
+ * @loc:
+ * @node:
+ * @byte_offset:
+ *
+ * TODO: Write me
+ */
 void 
 cong_location_set_node_and_byte_offset(CongLocation *loc, CongNodePtr node, int offset)
 {
@@ -117,6 +155,14 @@ cong_location_set_node_and_byte_offset(CongLocation *loc, CongNodePtr node, int
 	g_assert(cong_location_is_valid(loc));
 }
 
+/**
+ * cong_location_set_node_and_char_offset:
+ * @loc:
+ * @node:
+ * @char_offset:
+ *
+ * TODO: Write me
+ */
 void
 cong_location_set_node_and_char_offset(CongLocation *loc, CongNodePtr node, glong char_offset)
 {
@@ -140,16 +186,29 @@ cong_location_set_node_and_char_offset(CongLocation *loc, CongNodePtr node, glon
 	g_assert(cong_location_is_valid(loc));
 }
 
-
-
-
-gboolean cong_location_exists(const CongLocation *loc)
+/**
+ * cong_location_exists:
+ * @loc:
+ * 
+ * TODO: Write me
+ * Returns:
+ */
+gboolean 
+cong_location_exists(const CongLocation *loc)
 {
 	g_return_val_if_fail(loc != NULL, FALSE);
 	
 	return (loc->node!=NULL);
 }
 
+/**
+ * cong_location_equals:
+ * @loc0:
+ * @loc1:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 gboolean
 cong_location_equals(const CongLocation *loc0, const CongLocation *loc1)
 {
@@ -168,8 +227,14 @@ cong_location_equals(const CongLocation *loc0, const CongLocation *loc1)
 	return FALSE;	
 }
 
-
-enum CongNodeType
+/**
+ * cong_location_node_type:
+ * @loc:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+CongNodeType
 cong_location_node_type(const CongLocation *loc)
 {
 	g_return_val_if_fail(loc, CONG_NODE_TYPE_UNKNOWN);
@@ -178,15 +243,30 @@ cong_location_node_type(const CongLocation *loc)
 	return cong_node_type(loc->node);
 }
 
-gunichar cong_location_get_unichar(const CongLocation *loc)
+/**
+ * cong_location_get_unichar:
+ * @loc:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+gunichar 
+cong_location_get_unichar(const CongLocation *loc)
 {
 	g_return_val_if_fail(loc != NULL, '\0');
 	g_return_val_if_fail(loc->node != NULL, '\0');
-	g_return_val_if_fail(cong_location_node_type(loc) == CONG_NODE_TYPE_TEXT, '\0');
+	g_return_val_if_fail(cong_node_type_is_textual (cong_location_node_type(loc)), '\0');
 	
 	return g_utf8_get_char(xml_frag_data_nice(loc->node) + loc->byte_offset);
 }
 
+/**
+ * cong_location_get_utf7_pointer:
+ * @loc:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 gchar*
 cong_location_get_utf8_pointer(const CongLocation *loc)
 {
@@ -197,20 +277,14 @@ cong_location_get_utf8_pointer(const CongLocation *loc)
 	return NULL;
 }
 
-static gboolean
-has_same_namespace (CongNodePtr n1,
-		    CongNodePtr n2)
-{
-	g_return_val_if_fail (n1, FALSE);
-	g_return_val_if_fail (n2, FALSE);
-
-	/* FIXME: */
-	return TRUE;
-}
-
-/*
-  Are both ELEMENT nodes of the same tag type?
-*/
+/**
+ * cong_node_is_same_tag:
+ * @n1: a #CongNodePtr
+ * @n2: a #CongNodePtr
+ *
+ * Returns: %TRUE if both element nodes are of the same tag type,
+ * %FALSE otherwise.
+ */
 gboolean
 cong_node_is_same_tag (CongNodePtr n1, 
 		       CongNodePtr n2)
@@ -220,7 +294,7 @@ cong_node_is_same_tag (CongNodePtr n1,
 
 	if (CONG_NODE_TYPE_ELEMENT == cong_node_type(n1)) {
 		if (CONG_NODE_TYPE_ELEMENT == cong_node_type(n2)) {
-			if (has_same_namespace(n1,n2)) {
+			if (cong_util_ns_equality (n1->ns,n2->ns)) {
 				if (0==strcmp(n1->name, n2->name)) {
 					return TRUE;
 				}
@@ -231,6 +305,13 @@ cong_node_is_same_tag (CongNodePtr n1,
 	return FALSE;
 }
 
+/**
+ * cong_node_is_pure_whitespace_text_node:
+ * @node: a #CongNodePtr
+ *
+ * Returns: %TRUE if @node is a text node and is entirely whitespace,
+ * returns %FALSE otherwise.
+ */
 gboolean
 cong_node_is_pure_whitespace_text_node (CongNodePtr node)
 {
@@ -245,6 +326,14 @@ cong_node_is_pure_whitespace_text_node (CongNodePtr node)
 	return FALSE;
 }
 
+/**
+ * merge_tags:
+ * @cmd:
+ * @predator:
+ * @victim:
+ *
+ * TODO: Write me
+ */
 static void
 merge_tags (CongCommand *cmd,
 	    CongNodePtr predator,
@@ -283,6 +372,13 @@ merge_tags (CongCommand *cmd,
 	cong_document_end_edit (doc);
 }
 
+/**
+ * handle_tag_merging:
+ * @doc:
+ * @node:
+ *
+ * TODO: Write me
+ */
 static void
 handle_tag_merging (CongDocument *doc,
 		    CongNodePtr node)
@@ -332,6 +428,13 @@ handle_tag_merging (CongDocument *doc,
 
 }
 
+/**
+ * cong_location_del_next_char:
+ * @doc:
+ * @loc:
+ *
+ * TODO: Write me
+ */
 void
 cong_location_del_next_char (CongDocument *doc, 
 			     const CongLocation *loc)
@@ -395,24 +498,52 @@ cong_location_del_next_char (CongDocument *doc,
 	}
 }
 
+/**
+ * cong_location_xml_frag_prev:
+ * @loc: a #CongLocation
+ *
+ * TODO: Write me
+ * Returns:
+ */
 CongNodePtr
 cong_location_xml_frag_prev(const CongLocation *loc)
 {
 	return cong_node_prev(loc->node);
 }
 
+/**
+ * cong_location_xml_frag_next:
+ * @loc:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 CongNodePtr
 cong_location_xml_frag_next(const CongLocation *loc)
 {
 	return cong_node_next(loc->node);
 }
 
+/**
+ * cong_location_node:
+ * @loc:
+ * 
+ * TODO: Write me
+ * Returns:
+ */
 CongNodePtr
 cong_location_node(const CongLocation *loc)
 {
 	return loc->node;
 }
 
+/**
+ * cong_location_parent:
+ * @loc:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 CongNodePtr
 cong_location_parent(const CongLocation *loc)
 {
@@ -422,7 +553,13 @@ cong_location_parent(const CongLocation *loc)
 	return loc->node->parent;
 }
 
-
+/**
+ * cong_location_copy:
+ * @dst:
+ * @src:
+ *
+ * TODO: Write me
+ */
 void
 cong_location_copy(CongLocation *dst, const CongLocation *src)
 {
@@ -432,19 +569,38 @@ cong_location_copy(CongLocation *dst, const CongLocation *src)
 	*dst = *src;
 }
 
+/**
+ * is_valid_cusor_node:
+ * @node:
+ * @user_data:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 static gboolean
 is_valid_cursor_node (CongNodePtr node,
 		      gpointer user_data)
 {
 	g_return_val_if_fail (node, FALSE);
-	g_return_val_if_fail (user_data, FALSE); /* user_data is a CongDispspec */
+	g_return_val_if_fail (user_data, FALSE); /* user_data is a CongDocument */
 
 	return cong_node_is_valid_cursor_location (node);
 }
 
-gboolean cong_location_calc_prev_char(const CongLocation *input_loc, 
-				      CongDispspec *dispspec,
-				      CongLocation *output_loc)
+/**
+ * cong_location_calc_prev_char:
+ * @input_loc: the current #CongLocation
+ * @doc: the #CongDocument containing this #CongLocation
+ * @output_loc: the #CongLocation that is computed
+ *
+ * Calculates a new #CongLocation when the left key is pressed
+ * 
+ * Returns: %TRUE if succeeded
+ */
+gboolean 
+cong_location_calc_prev_char(const CongLocation *input_loc, 
+			     CongDocument *doc,
+			     CongLocation *output_loc)
 {
 	CongNodePtr n;
 
@@ -452,12 +608,12 @@ gboolean cong_location_calc_prev_char(const CongLocation *input_loc,
 	printf("<- [curs]\n");
 #endif
 
-	g_return_val_if_fail(input_loc, FALSE);
-	g_return_val_if_fail(dispspec, FALSE);
-	g_return_val_if_fail(output_loc, FALSE);
+	g_return_val_if_fail (input_loc, FALSE);
+	g_return_val_if_fail (doc, FALSE);
+	g_return_val_if_fail (output_loc, FALSE);
 	
 	n = input_loc->node;
-	if (is_valid_cursor_node(input_loc->node, dispspec) && input_loc->byte_offset) { 
+	if (is_valid_cursor_node(input_loc->node, doc) && input_loc->byte_offset) { 
 
 		gchar *this_char;
 		gchar *prev_char;
@@ -478,10 +634,10 @@ gboolean cong_location_calc_prev_char(const CongLocation *input_loc,
 	}
 	n = cong_node_calc_prev_node_satisfying (n, 
 						 is_valid_cursor_node, 
-						 dispspec);
+						 doc);
 
 	if (n) {
-		g_assert (is_valid_cursor_node (n, dispspec));
+		g_assert (is_valid_cursor_node (n, doc));
 
 		/* FIXME: UTF-8 issues here! */
 		cong_location_set_node_and_byte_offset(output_loc,n, strlen(xml_frag_data_nice(n)));
@@ -491,9 +647,19 @@ gboolean cong_location_calc_prev_char(const CongLocation *input_loc,
 	}
 }
 
-
-gboolean cong_location_calc_next_char(const CongLocation *input_loc,
-				      CongDispspec *dispspec,
+/**
+ * cong_location_calc_next_char:
+ * @input_loc: the current #CongLocation
+ * @doc: the #CongDocument containing this #CongLocation
+ * @output_loc: the #CongLocation that is computed
+ *
+ * Calculates a new #CongLocation when the right key is pressed
+ * 
+ * Returns: %TRUE if succeeded
+ */
+gboolean 
+cong_location_calc_next_char(const CongLocation *input_loc,
+				      CongDocument *doc,
 				      CongLocation *output_loc)
 {
 	CongNodePtr n;
@@ -502,14 +668,14 @@ gboolean cong_location_calc_next_char(const CongLocation *input_loc,
 	printf("[curs] ->\n");
 #endif
 
-	g_return_val_if_fail(input_loc, FALSE);
-	g_return_val_if_fail(dispspec, FALSE);
-	g_return_val_if_fail(output_loc, FALSE);
+	g_return_val_if_fail (input_loc, FALSE);
+	g_return_val_if_fail (doc, FALSE);
+	g_return_val_if_fail (output_loc, FALSE);
 
 
 	n = input_loc->node;
 
-	if (is_valid_cursor_node (n, dispspec) && cong_location_get_unichar(input_loc)) {
+	if (is_valid_cursor_node (n, doc) && cong_location_get_unichar(input_loc)) {
 		gchar *this_char;
 		gchar *next_char;
 
@@ -531,7 +697,7 @@ gboolean cong_location_calc_next_char(const CongLocation *input_loc,
 	 * so we find the next node satisfying is_valid_cursor_node. */ 
 	n = cong_node_calc_next_node_satisfying (n, 
 						 is_valid_cursor_node, 
-						 dispspec);
+						 doc);
 
 	if (n) {
 		/* Found next node, so we return a CongLocation pointing to its first character. */
@@ -543,37 +709,19 @@ gboolean cong_location_calc_next_char(const CongLocation *input_loc,
 	return FALSE;
 }
 
-static void make_pango_log_attr_for_node(CongDocument *doc,
-					 CongNodePtr node,
-					 PangoLogAttr **pango_log_attrs,
-					 int *attrs_len)
-{
-	PangoLanguage *language;
-
-	g_return_if_fail(doc);
-	g_return_if_fail(node);
-	g_return_if_fail(node->content);
-	g_return_if_fail(pango_log_attrs);
-	g_return_if_fail(attrs_len);
-
-	language = cong_document_get_language_for_node(doc, node);
-
-	*attrs_len = g_utf8_strlen(node->content,-1)+1;
-
-	*pango_log_attrs = g_new(PangoLogAttr, (*attrs_len));
-	
-	pango_get_log_attrs(node->content,
-			    strlen(node->content), /* length in bytes */
-			    -1,
-			    language,
-			    *pango_log_attrs,
-			    *attrs_len);
-
-}
-
-gboolean cong_location_calc_prev_word(const CongLocation *input_loc, 
-				      CongDocument *doc,
-				      CongLocation *output_loc)
+/**
+ * cong_location_calc_prev_word:
+ * @input_loc:
+ * @doc:
+ * @output_loc:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+gboolean 
+cong_location_calc_prev_word(const CongLocation *input_loc, 
+			     CongDocument *doc,
+			     CongLocation *output_loc)
 {
 	PangoLogAttr *pango_log_attr=NULL;
 	int attrs_len=0;
@@ -582,7 +730,7 @@ gboolean cong_location_calc_prev_word(const CongLocation *input_loc,
 	g_return_val_if_fail(doc, FALSE);
 	g_return_val_if_fail(output_loc, FALSE);
 
-	make_pango_log_attr_for_node(doc,
+	cong_document_make_pango_log_attr_for_node(doc,
 				     input_loc->node,
 				     &pango_log_attr,
 				     &attrs_len);
@@ -622,9 +770,19 @@ gboolean cong_location_calc_prev_word(const CongLocation *input_loc,
 	}
 }
 
-gboolean cong_location_calc_next_word(const CongLocation *input_loc, 
-				      CongDocument *doc,
-				      CongLocation *output_loc)
+/**
+ * cong_location_calc_next_word:
+ * @input_loc:
+ * @doc:
+ * @output_loc:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+gboolean 
+cong_location_calc_next_word(const CongLocation *input_loc, 
+			     CongDocument *doc,
+			     CongLocation *output_loc)
 {
 	PangoLogAttr *pango_log_attr=NULL;
 	int attrs_len=0;
@@ -633,7 +791,7 @@ gboolean cong_location_calc_next_word(const CongLocation *input_loc,
 	g_return_val_if_fail(doc, FALSE);
 	g_return_val_if_fail(output_loc, FALSE);
 
-	make_pango_log_attr_for_node(doc, 
+	cong_document_make_pango_log_attr_for_node(doc, 
 				     input_loc->node,
 				     &pango_log_attr,
 				     &attrs_len);
@@ -670,6 +828,13 @@ gboolean cong_location_calc_next_word(const CongLocation *input_loc,
 	}
 }
 
+/**
+ * get_root_node:
+ * @node:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 static CongNodePtr
 get_root_node (CongNodePtr node)
 {
@@ -682,30 +847,44 @@ get_root_node (CongNodePtr node)
 	return node;
 }
 
+/**
+ * get_enclosing_structural_element:
+ * @node:
+ * @doc:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 static CongNodePtr
 get_enclosing_structural_element (CongNodePtr node,
-				  const CongDispspec *dispspec)
+				  CongDocument *doc)
 {
 	g_assert (node);
-	g_assert (dispspec);
+	g_assert (doc);
 
 	while (node) {
 		if (cong_node_type (node)==CONG_NODE_TYPE_ELEMENT) {
-			CongDispspecElement* element;
+			CongDispspecElement* ds_element;
 
-			element = cong_dispspec_lookup_node(dispspec, node);
+			ds_element = cong_document_get_dispspec_element_for_node (doc, node);
+
+			if (ds_element) {
 			
-			switch (cong_dispspec_element_type (element)) {
-			default: g_assert_not_reached();
-			case CONG_ELEMENT_TYPE_STRUCTURAL:
-			case CONG_ELEMENT_TYPE_PLUGIN:
+				switch (cong_dispspec_element_type (ds_element)) {
+				default: g_assert_not_reached();
+				case CONG_ELEMENT_TYPE_STRUCTURAL:
+				case CONG_ELEMENT_TYPE_PLUGIN:
+					return node;
+					
+				case CONG_ELEMENT_TYPE_SPAN:
+				case CONG_ELEMENT_TYPE_INSERT:
+				case CONG_ELEMENT_TYPE_EMBED_EXTERNAL_FILE:
+				case CONG_ELEMENT_TYPE_UNKNOWN:
+					break;
+				}
+			} else {
+				/* For the purposes of this function, we treat an unknown element as a structural element: */
 				return node;
-				
-			case CONG_ELEMENT_TYPE_SPAN:
-			case CONG_ELEMENT_TYPE_INSERT:
-			case CONG_ELEMENT_TYPE_EMBED_EXTERNAL_FILE:
-			case CONG_ELEMENT_TYPE_UNKNOWN:
-				break;
 			}
 		}
 
@@ -716,21 +895,31 @@ get_enclosing_structural_element (CongNodePtr node,
 	return NULL;
 }
 
-gboolean cong_location_calc_document_start(const CongLocation *input_loc, 
-					   CongDispspec *dispspec,
-					   CongLocation *output_loc)
+/**
+ * cong_location_calc_document_start:
+ * @input_loc:
+ * @doc:
+ * @output_loc:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+gboolean 
+cong_location_calc_document_start(const CongLocation *input_loc, 
+				  CongDocument *doc,
+				  CongLocation *output_loc)
 {
 	CongNodePtr root_node;
 
-	g_return_val_if_fail(input_loc, FALSE);
-	g_return_val_if_fail(dispspec, FALSE);
-	g_return_val_if_fail(output_loc, FALSE);
+	g_return_val_if_fail (input_loc, FALSE);
+	g_return_val_if_fail (doc, FALSE);
+	g_return_val_if_fail (output_loc, FALSE);
 
 	root_node = get_root_node (input_loc->node);
 	if (root_node) {
 		CongNodePtr node = cong_node_calc_first_node_in_subtree_satisfying (root_node, 
 										    is_valid_cursor_node,
-										    dispspec);
+										    doc);
 		if (node) {
 			cong_location_set_to_start_of_node (output_loc, node);
 			return TRUE;
@@ -739,25 +928,36 @@ gboolean cong_location_calc_document_start(const CongLocation *input_loc,
 
 	return FALSE;
 }
-gboolean cong_location_calc_line_start(const CongLocation *input_loc, 
-				      CongDispspec *dispspec,
-				      CongLocation *output_loc)
+
+/**
+ * cong_location_calc_line_start:
+ * @input_loc:
+ * @doc:
+ * @output_loc:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+gboolean 
+cong_location_calc_line_start(const CongLocation *input_loc, 
+			      CongDocument *doc,
+			      CongLocation *output_loc)
 {
 	CongNodePtr enclosing_structural_element;
 
-	g_return_val_if_fail(input_loc, FALSE);
-	g_return_val_if_fail(dispspec, FALSE);
-	g_return_val_if_fail(output_loc, FALSE);
+	g_return_val_if_fail (input_loc, FALSE);
+	g_return_val_if_fail (doc, FALSE);
+	g_return_val_if_fail (output_loc, FALSE);
 
 	/* This actually calculates the start of the text within the current structural node, rather than the start of the current line (as it's much easier).
 	   (This was part of bug #109698)
 	*/
 	enclosing_structural_element = get_enclosing_structural_element (input_loc->node,
-									 dispspec);
+									 doc);
 	if (enclosing_structural_element) {
 		CongNodePtr node = cong_node_calc_first_node_in_subtree_satisfying (enclosing_structural_element, 
 										    is_valid_cursor_node,
-										    dispspec);
+										    doc);
 		if (node) {
 			cong_location_set_to_start_of_node (output_loc, node);
 			return TRUE;
@@ -767,21 +967,31 @@ gboolean cong_location_calc_line_start(const CongLocation *input_loc,
 	return FALSE;
 }
 
-gboolean cong_location_calc_document_end(const CongLocation *input_loc, 
-					 CongDispspec *dispspec,
-					 CongLocation *output_loc)
+/**
+ * cong_location_calc_document_end:
+ * @input_loc:
+ * @doc:
+ * @output_loc:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+gboolean 
+cong_location_calc_document_end(const CongLocation *input_loc, 
+				CongDocument *doc,
+				CongLocation *output_loc)
 {
 	CongNodePtr root_node;
 
-	g_return_val_if_fail(input_loc, FALSE);
-	g_return_val_if_fail(dispspec, FALSE);
-	g_return_val_if_fail(output_loc, FALSE);
+	g_return_val_if_fail (input_loc, FALSE);
+	g_return_val_if_fail (doc, FALSE);
+	g_return_val_if_fail (output_loc, FALSE);
 
 	root_node = get_root_node (input_loc->node);
 	if (root_node) {
 		CongNodePtr node = cong_node_calc_final_node_in_subtree_satisfying (root_node, 									  
 										    is_valid_cursor_node,
-										    dispspec);
+										    doc);
 		if (node) {
 			cong_location_set_to_end_of_node (output_loc, node);
 			return TRUE;
@@ -791,25 +1001,35 @@ gboolean cong_location_calc_document_end(const CongLocation *input_loc,
 	return FALSE;
 }
 
-gboolean cong_location_calc_line_end(const CongLocation *input_loc, 
-				     CongDispspec *dispspec,
-				     CongLocation *output_loc)
+/**
+ * cong_location_calc_line_end:
+ * @input_loc:
+ * @doc:
+ * @output_loc:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+gboolean 
+cong_location_calc_line_end(const CongLocation *input_loc, 
+			    CongDocument *doc,
+			    CongLocation *output_loc)
 {
 	CongNodePtr enclosing_structural_element;
 
-	g_return_val_if_fail(input_loc, FALSE);
-	g_return_val_if_fail(dispspec, FALSE);
-	g_return_val_if_fail(output_loc, FALSE);
+	g_return_val_if_fail (input_loc, FALSE);
+	g_return_val_if_fail (doc, FALSE);
+	g_return_val_if_fail (output_loc, FALSE);
 
 	/* This actually calculates the end of the text within the current structural node, rather than the start of the current line (as it's much easier).
 	   (This was part of bug #109698)
 	*/
 	enclosing_structural_element = get_enclosing_structural_element (input_loc->node,
-									 dispspec);
+									 doc);
 	if (enclosing_structural_element) {
 		CongNodePtr node = cong_node_calc_final_node_in_subtree_satisfying (enclosing_structural_element, 
 										    is_valid_cursor_node,
-										    dispspec);
+										    doc);
 		if (node) {
 			cong_location_set_to_end_of_node (output_loc, node);
 			return TRUE;
@@ -819,32 +1039,62 @@ gboolean cong_location_calc_line_end(const CongLocation *input_loc,
 	return FALSE;
 }
 
-gboolean cong_location_calc_prev_page(const CongLocation *input_loc, 
-				      CongDispspec *dispspec,
-				      CongLocation *output_loc)
+/**
+ * cong_location_calc_prev_page:
+ * @input_loc:
+ * @doc:
+ * @output_loc:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+gboolean 
+cong_location_calc_prev_page(const CongLocation *input_loc, 
+			     CongDocument *doc,
+			     CongLocation *output_loc)
 {
-	g_return_val_if_fail(input_loc, FALSE);
-	g_return_val_if_fail(dispspec, FALSE);
-	g_return_val_if_fail(output_loc, FALSE);
+	g_return_val_if_fail (input_loc, FALSE);
+	g_return_val_if_fail (doc, FALSE);
+	g_return_val_if_fail (output_loc, FALSE);
 
 	CONG_DO_UNIMPLEMENTED_DIALOG(NULL, _("Calculating previous page"));
 
 	return FALSE;
 }
 
-gboolean cong_location_calc_next_page(const CongLocation *input_loc, 
-				      CongDispspec *dispspec,
-				      CongLocation *output_loc)
+/**
+ * cong_location_calc_next_page:
+ * @input_loc:
+ * @doc:
+ * @output_loc:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+gboolean 
+cong_location_calc_next_page(const CongLocation *input_loc, 
+			     CongDocument *doc,
+			     CongLocation *output_loc)
 {
-	g_return_val_if_fail(input_loc, FALSE);
-	g_return_val_if_fail(dispspec, FALSE);
-	g_return_val_if_fail(output_loc, FALSE);
+	g_return_val_if_fail (input_loc, FALSE);
+	g_return_val_if_fail (doc, FALSE);
+	g_return_val_if_fail (output_loc, FALSE);
 
 	CONG_DO_UNIMPLEMENTED_DIALOG(NULL, _("Calculating next page"));
 
 	return FALSE;
 }
 
+/**
+ * cong_location_calc_word_extent:
+ * @input_loc:
+ * @doc:
+ * @output_start_of_word:
+ * @output_end_of_word:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 gboolean
 cong_location_calc_word_extent(const CongLocation *input_loc, 
 			       CongDocument *doc,
@@ -865,7 +1115,7 @@ cong_location_calc_word_extent(const CongLocation *input_loc,
 		   input_loc->node->content);
 #endif
 
-	make_pango_log_attr_for_node(doc,
+	cong_document_make_pango_log_attr_for_node(doc,
 				     input_loc->node,
 				     &pango_log_attr,
 				     &attrs_len);
@@ -892,7 +1142,7 @@ cong_location_calc_word_extent(const CongLocation *input_loc,
 		/* Scan forwards to next is_word_end: */
 		{
 			glong end_char_index = char_index;
-			while (end_char_index<attrs_len) {
+			while (end_char_index<(attrs_len-1)) {
 				
 				if (pango_log_attr[++end_char_index].is_word_end) {
 					break;
@@ -922,7 +1172,7 @@ cong_location_calc_word_extent(const CongLocation *input_loc,
 #if 0
 gboolean
 cong_location_calc_prev_text_node (const CongLocation *input_loc, 
-				   CongDispspec *dispspec,
+				   CongDocument *doc,
 				   CongLocation *output_loc)
 {
 #error
@@ -930,13 +1180,21 @@ cong_location_calc_prev_text_node (const CongLocation *input_loc,
 
 gboolean
 cong_location_calc_next_text_node (const CongLocation *input_loc,
-				   CongDispspec *dispspec,
+				   CongDocument *doc,
 				   CongLocation *output_loc)
 {
 #error
 }
 #endif
 
+/**
+ * cong_location_copy_with_ref:
+ * @doc:
+ * @dst:
+ * @src:
+ *
+ * TODO: Write me
+ */
 void
 cong_location_copy_with_ref (CongDocument *doc, 
 			     CongLocation *dst,
@@ -957,6 +1215,13 @@ cong_location_copy_with_ref (CongDocument *doc,
 	}
 }
 
+/**
+ * cong_location_nullify_with_ref:
+ * @doc:
+ * @loc:
+ *
+ * TODO: Write me
+ */
 void
 cong_location_nullify_with_ref (CongDocument *doc, 
 				CongLocation *loc)
