@@ -30,6 +30,8 @@
 #include "cong-util.h"
 #include "cong-dtd.h"
 
+#include <string.h>
+
 #define LOG_CONG_NODE_PRIVATE_MODIFICATIONS 0
 #if LOG_CONG_NODE_PRIVATE_MODIFICATIONS
 #define LOG_NODE_PRIVATE_MODIFICATION(x) g_message(x)
@@ -42,14 +44,30 @@
 /* Internal function declarations: */
 
 /* Exported function definitions: */
-CongNodePtr cong_node_prev(CongNodePtr node)
+/**
+ * cong_node_prev:
+ * @node:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+CongNodePtr 
+cong_node_prev(CongNodePtr node)
 {
 	g_return_val_if_fail(node, NULL);
 
 	return node->prev;	
 }
 
-CongNodePtr cong_node_next(CongNodePtr node)
+/**
+ * cong_node_next:
+ * @node:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+CongNodePtr 
+cong_node_next(CongNodePtr node)
 {
 	g_assert(node);
 	g_return_val_if_fail(node, NULL);
@@ -57,21 +75,45 @@ CongNodePtr cong_node_next(CongNodePtr node)
 	return node->next;
 }
 
-CongNodePtr cong_node_first_child(CongNodePtr node)
+/**
+ * cong_node_first_child:
+ * @node:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+CongNodePtr 
+cong_node_first_child(CongNodePtr node)
 {
 	g_return_val_if_fail(node, NULL);
 
 	return node->children;
 }
 
-CongNodePtr cong_node_parent(CongNodePtr node)
+/**
+ * cong_node_parent:
+ * @node:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+CongNodePtr 
+cong_node_parent(CongNodePtr node)
 {
 	g_return_val_if_fail(node, NULL);
 
 	return node->parent;
 }
 
-enum CongNodeType cong_node_type(CongNodePtr node)
+/**
+ * cong_node_type:
+ * @node:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+CongNodeType 
+cong_node_type(CongNodePtr node)
 {
 	g_return_val_if_fail(node, CONG_NODE_TYPE_UNKNOWN);
 
@@ -127,6 +169,16 @@ enum CongNodeType cong_node_type(CongNodePtr node)
 
 }
 
+/** 
+ * cong_node_is_element:
+ * @node:
+ * @ns_uri:
+ * @local_name:
+ *
+ * Handy method for deciding if you've found a element with the given name, as opposed to text nodes, comments, elements with other names etc.
+ *
+ * Returns: TRUE if the node is an element with the correct name, FALSE otherwise
+ */
 gboolean 
 cong_node_is_element (CongNodePtr node, 
 		      const gchar *ns_uri,
@@ -148,6 +200,61 @@ cong_node_is_element (CongNodePtr node,
 	return FALSE;
 }
 
+/** 
+ * cong_node_is_element_from_set:
+ * @node:
+ * @ns_uri: URI of the namespace shared by all the element in the search set
+ * @local_name_array: array of element local names within the namespace
+ * @num_local_names: size of search array
+ * @output_index: pointer to write index of result to, or NULL if you don't care
+ *
+ * Handy method for deciding if you've found a element with one of the given names in the set, as opposed to text nodes, comments, elements with other names etc.
+ *
+ * Returns: TRUE if the node is an element with the correct name, FALSE otherwise
+ */
+gboolean 
+cong_node_is_element_from_set (CongNodePtr node, 
+			       const gchar *ns_uri,
+			       const gchar **local_name_array,
+			       guint num_local_names,
+			       guint *output_index)
+{
+	g_return_val_if_fail (node, FALSE);
+	g_return_val_if_fail (local_name_array, FALSE);
+
+	if (node->type==XML_ELEMENT_NODE) {
+		const gchar *node_ns_uri = cong_node_get_ns_uri (node);
+		guint i;
+
+		if (!cong_util_ns_uri_equality (ns_uri, node_ns_uri)) {
+			return FALSE;
+		}
+
+		for (i=0;i<num_local_names;i++) {
+			g_assert (local_name_array[i]);
+
+			if (0==strcmp (local_name_array[i], node->name)) {
+
+				if (output_index) {
+					*output_index = i;					
+				}
+
+				return TRUE;
+			}
+		}
+	}
+
+	return FALSE;
+	
+}
+
+/**
+ * cong_node_get_ns:
+ * @node:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 xmlNsPtr
 cong_node_get_ns (CongNodePtr node)
 {
@@ -156,6 +263,13 @@ cong_node_get_ns (CongNodePtr node)
 	return node->ns;
 }
 
+/**
+ * cong_node_get_ns_uri:
+ * @node:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 const gchar*
 cong_node_get_ns_uri (CongNodePtr node)
 {
@@ -168,6 +282,13 @@ cong_node_get_ns_uri (CongNodePtr node)
 	}
 }
 
+/**
+ * cong_node_get_ns_prefix:
+ * @node:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 const gchar*
 cong_node_get_ns_prefix (CongNodePtr node)
 {
@@ -180,6 +301,13 @@ cong_node_get_ns_prefix (CongNodePtr node)
 	}
 }
 
+/**
+ * cong_node_get_local_name:
+ * @node:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 const gchar* 
 cong_node_get_local_name (CongNodePtr node)
 {
@@ -189,6 +317,15 @@ cong_node_get_local_name (CongNodePtr node)
 	return node->name;
 }
 
+/**
+ * cong_node_get_qualified_name:
+ * @node: an XML element
+ *
+ * Builds a string of the form "ns_prefix:local_name" for an element inside a namespace
+ * or simply "local_name" for the rest.
+ *
+ * Returns: a freshly-allocated string which the caller must g_free
+ */
 gchar*
 cong_node_get_qualified_name (CongNodePtr node)
 {
@@ -204,6 +341,16 @@ cong_node_get_qualified_name (CongNodePtr node)
 	}	
 }
 
+/*
+ * cong_node_get_ns_for_uri:
+ * @node:  the context in which to look for the prefix
+ * @ns_uri: the namespace URI
+ *
+ * Lookup a namespace URI; find the appropriate xmlNsPtr defined, 
+ * or NULL if not found.
+ *
+ * Returns:  the #xmlNsPtr if found, or NULL if not found.
+ */
 xmlNsPtr
 cong_node_get_ns_for_uri (CongNodePtr node, 
 			  const gchar *ns_uri)
@@ -213,6 +360,16 @@ cong_node_get_ns_for_uri (CongNodePtr node,
 				  ns_uri);
 }
 
+/*
+ * cong_node_get_ns_for_prefix:
+ * @node:  the context in which to look for the prefix
+ * @prefix: the prefix
+ *
+ * Lookup a namespace prefix; find the appropriate xmlNsPtr defined
+ * for that prefix, or NULL if not found.
+ *
+ * Returns:  the #xmlNsPtr if found, or NULL if not found.
+ */
 xmlNsPtr
 cong_node_get_ns_for_prefix (CongNodePtr node, 
 			     const gchar *prefix)
@@ -225,15 +382,80 @@ cong_node_get_ns_for_prefix (CongNodePtr node,
 			    prefix);
 }
 
+/**
+ * conf_node_get_attr_ns:
+ * @node: an XML element
+ * @qualified_attr_name: An qualified attribute name with an optional namespace prefix.
+ * @output_attr_name: Stores the location of the local_name in @qualified_name.
+ *
+ * Splits the qualified name into the prefix and the local name,
+ * and searches the namespace of the prefix. All namespaces of the
+ * @node are searched. If no prefix is availible NULL is returned.
+ * see: Namespaces in XML / 5.3 Uniqueness of Attributes.
+ *
+ * Returns: A pointer to the namespace, can be NULL.
+ */
+xmlNsPtr 
+cong_node_get_attr_ns(CongNodePtr node, 
+		      const char *qualified_name, 
+		      const char **output_name)
+{
+	g_return_val_if_fail(node != NULL, NULL);
+	g_return_val_if_fail(qualified_name != NULL, NULL);
+	g_return_val_if_fail(output_name != NULL, NULL);
+
+	/* get namespace prefix */
+		
+	*output_name = strchr(qualified_name, ':');
+
+	if(*output_name == NULL) {
+		*output_name = qualified_name;
+		return NULL;
+	} else {
+		gchar *prefix;
+		xmlNsPtr ns;
+
+		prefix = g_strndup(qualified_name, 
+				   (*output_name) - qualified_name);
+
+		/* go after the colon. */
+		(*output_name) ++;
+
+		ns = cong_node_get_ns_for_prefix(node,
+						 prefix);
+
+		g_free(prefix);
+
+		return ns;
+	}	
+}
+
 /* Method for getting an XPath to the node: */
-gchar *cong_node_get_path(CongNodePtr node)
+/**
+ * cong_node_get_path:
+ * @node: an XML node
+ *
+ * Method for getting an XPath to the node.
+ *
+ * Returns: the XPath as a freshly allocated string, which must be freed using g_free
+ */
+gchar *
+cong_node_get_path(CongNodePtr node)
 {
 	g_return_val_if_fail(node, NULL);
 
 	return xmlGetNodePath(node);
 }
 
-gchar *cong_node_debug_description(CongNodePtr node)
+/**
+ * cong_node_debug_description:
+ * @node:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+gchar *
+cong_node_debug_description(CongNodePtr node)
 {
 	gchar *result = NULL; 
 	gchar *xpath;
@@ -335,9 +557,15 @@ static const gchar* node_type_names[CONG_NODE_TYPE_NUM]=
 	"CONG_NODE_TYPE_XINCLUDE_END"
 };
 	
-
-
-const gchar *cong_node_type_description(enum CongNodeType node_type)
+/**
+ * cong_node_type_description:
+ * @node_type:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+const gchar *
+cong_node_type_description(CongNodeType node_type)
 {
 	g_return_val_if_fail(node_type<CONG_NODE_TYPE_NUM,"(invalid type)");
 
@@ -345,16 +573,124 @@ const gchar *cong_node_type_description(enum CongNodeType node_type)
 
 }
 
-/* Methods for accessing attribute values: */
-CongXMLChar* cong_node_get_attribute(CongNodePtr node, const CongXMLChar* attribute_name)
+/**
+ * cong_node_type_is_textual:
+ * @node_type:
+ *
+ * Returns: TRUE iff the node type is text, a CDATA section, or a comment.
+ */
+gboolean
+cong_node_type_is_textual (CongNodeType node_type)
 {
-	g_return_val_if_fail(node, NULL);
-	g_return_val_if_fail(attribute_name, NULL);
+	switch (node_type) {
+	default: 
+		return FALSE;
 
-	return xmlGetProp(node, attribute_name);
+	case CONG_NODE_TYPE_TEXT:
+	case CONG_NODE_TYPE_CDATA_SECTION:
+	case CONG_NODE_TYPE_COMMENT:
+		return TRUE;
+	}
 }
 
-void cong_node_self_test(CongNodePtr node)
+/**
+ * cong_node_type_is_textual_content:
+ * @node_type:
+ *
+ * Returns: TRUE iff the node type is text, a CDATA section (not comments).
+ */
+gboolean
+cong_node_type_is_textual_content (CongNodeType node_type)
+{
+	switch (node_type) {
+	default: 
+		return FALSE;
+
+	case CONG_NODE_TYPE_TEXT:
+	case CONG_NODE_TYPE_CDATA_SECTION:
+		return TRUE;
+	}
+}
+
+/* Methods for accessing attribute values: */
+/**
+ * cong_node_get_attribute:
+ * @node: XML node which has the attribute.
+ * @ns_ptr: Attribute's namespace, can be NULL
+ *          (if it is the default namespace it MUST NOT be NULL but the coresponding
+ *          xmlNs).
+ * @local_attribute_name: Name of the attribute, without namespace prefix.
+ *
+ * Returns the content of the attribute specified through @local_attribute_name and
+ * @ns_ptr.
+ *
+ * Returns: The content of the attribute, to be freed by the caller.
+ *          Will be NULL if not found in node and no default in DTD available
+ */
+CongXMLChar* 
+cong_node_get_attribute(CongNodePtr node,
+			xmlNs* ns_ptr, 
+			const CongXMLChar* local_attribute_name)
+{
+	g_return_val_if_fail(node, NULL);
+	g_return_val_if_fail(local_attribute_name, NULL);
+	
+	if(ns_ptr == NULL) {
+		return xmlGetNoNsProp(node, local_attribute_name);
+	} else {
+		return xmlGetNsProp(node, local_attribute_name, ns_ptr->href);
+	}
+}
+
+/**
+ * cong_node_has_attribute:
+ * @node: XML node which has the attribute.
+ * @ns_ptr: Attribute's namespace, can be NULL
+ *             (if it is the default namespace it MUST NOT be NULL but the coresponding
+ *              xmlNs).
+ * @local_attribute_name: Name of the attribute, without namespace prefix.
+ *
+ * Returns: Returns TRUE if the attribute specified through @local_attribute_name and
+ *          @ns_ptr is found in the node or as default in the DTD.
+ */
+gboolean 
+cong_node_has_attribute(CongNodePtr node,
+			xmlNs* ns_ptr, 
+			const CongXMLChar* local_attribute_name)
+{
+	g_return_val_if_fail(node, FALSE);
+	g_return_val_if_fail(local_attribute_name, FALSE);
+	
+	if(ns_ptr == NULL) {
+		xmlAttr *attr = xmlHasProp(node, local_attribute_name);
+
+		/* now check, if there is any namespace,
+		 * if there is a prefix. */
+		if (attr == NULL) {
+			return FALSE;
+		} else if (attr->ns != NULL &&
+			   attr->ns->prefix != NULL) {
+			if (strcmp(attr->ns->prefix, "") == 0) {
+				return TRUE;
+			} else {
+				return FALSE;
+			}
+		} else {
+			return TRUE;
+		}
+	} else {		
+		return xmlHasNsProp(node, local_attribute_name, ns_ptr->href) != NULL;
+	}
+}
+
+/**
+ * cong_node_self_test:
+ * @node:
+ *
+ * TODO: Write me
+ */
+void 
+cong_node_self_test(CongNodePtr node)
 {
 	CongNodePtr iter;
 
@@ -452,7 +788,14 @@ void cong_node_self_test(CongNodePtr node)
 	}
 }
 
-void cong_node_self_test_recursive(CongNodePtr node)
+/**
+ * cong_node_self_test_recursive:
+ * @node:
+ *
+ * TODO: Write me
+ */
+void 
+cong_node_self_test_recursive(CongNodePtr node)
 {
 
 	g_return_if_fail(node);
@@ -470,16 +813,32 @@ void cong_node_self_test_recursive(CongNodePtr node)
 	}
 }
 
-int cong_node_get_length(CongNodePtr node)
+/**
+ * cong_node_get_length:
+ * @node:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+int 
+cong_node_get_length(CongNodePtr node)
 {
 	/* get length of content; does not include the zero terminator */
-	g_return_val_if_fail( (cong_node_type(node) == CONG_NODE_TYPE_TEXT) || (cong_node_type(node) == CONG_NODE_TYPE_COMMENT), 0);
+	g_return_val_if_fail( cong_node_type_is_textual (cong_node_type(node)), 0);
 
 	return xmlStrlen(node->content);
 	
 }
 
-gboolean cong_node_should_recurse(CongNodePtr node)
+/**
+ * cong_node_should_recurse:
+ * @node:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+gboolean 
+cong_node_should_recurse(CongNodePtr node)
 {
 	g_return_val_if_fail(node, FALSE);
 
@@ -517,6 +876,15 @@ gboolean cong_node_should_recurse(CongNodePtr node)
 }
 
 /* Construction: */
+/**
+ * cong_node_new_element:
+ * @ns:
+ * @tagname:
+ * @doc:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 CongNodePtr 
 cong_node_new_element (xmlNsPtr xml_ns, 
 		       const gchar *local_name, 
@@ -532,6 +900,14 @@ cong_node_new_element (xmlNsPtr xml_ns,
 			      NULL); /* FIXME: audit the character types here */
 }
 
+/**
+ * cong_node_new_element_from_dispspec:
+ * @element:
+ * @doc:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 CongNodePtr
 cong_node_new_element_from_dispspec (CongDispspecElement *element, 
 				     CongDocument *doc)
@@ -550,6 +926,54 @@ cong_node_new_element_from_dispspec (CongDispspecElement *element,
 			      NULL);
 }
 
+CongNodePtr 
+cong_node_new_element_full (xmlDocPtr xml_doc, 
+			    const gchar *ns_uri,
+			    const gchar *local_name)
+{
+	xmlNsPtr xml_ns;
+
+	g_return_val_if_fail (xml_doc, NULL);
+	g_return_val_if_fail (local_name, NULL);
+
+	xml_ns = xmlSearchNsByHref (xml_doc,
+				    (xmlNodePtr)xml_doc, /* FIXME: is this correct? */
+				    ns_uri);
+	return xmlNewDocNode (xml_doc,
+			      xml_ns,
+			      local_name, 
+			      NULL);
+}
+
+CongNodePtr 
+cong_node_new_element_full_with_content (xmlDocPtr xml_doc, 
+					 const gchar *ns_uri,
+					 const gchar *local_name,
+					 const gchar *content)
+{
+	xmlNsPtr xml_ns;
+
+	g_return_val_if_fail (xml_doc, NULL);
+	g_return_val_if_fail (local_name, NULL);
+	g_return_val_if_fail (content, NULL);
+
+	xml_ns = xmlSearchNsByHref (xml_doc,
+				    (xmlNodePtr)xml_doc, /* FIXME: is this correct? */
+				    ns_uri);
+	return xmlNewDocNode (xml_doc,
+			      xml_ns,
+			      local_name, 
+			      content);
+}
+
+/**
+ * cong_node_new_text:
+ * @text:
+ * @doc:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 CongNodePtr 
 cong_node_new_text (const char *text, 
 		    CongDocument *doc)
@@ -557,6 +981,15 @@ cong_node_new_text (const char *text,
 	return cong_node_new_text_len(text, strlen(text),doc);
 }
 
+/**
+ * cong_node_new_text_len:
+ * @text:
+ * @len:
+ * @doc:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 CongNodePtr 
 cong_node_new_text_len (const char *text, 
 			int len, 
@@ -568,15 +1001,116 @@ cong_node_new_text_len (const char *text,
 	return xmlNewDocTextLen(cong_document_get_xml(doc), text, len); /* FIXME: audit the character types here */
 }
 
+CongNodePtr
+cong_node_new_cdata_section (const gchar *text, 
+			     CongDocument *doc)
+{
+	return cong_node_new_cdata_section_len (text, strlen(text), doc);
+}
+
+CongNodePtr
+cong_node_new_cdata_section_len (const gchar *text, 
+				 int len, 
+				 CongDocument *doc)
+{
+	return xmlNewCDataBlock	(cong_document_get_xml(doc),
+				 text,
+				 len);
+}
+
+CongNodePtr
+cong_node_new_comment (const gchar *comment, 
+		       CongDocument *doc)
+{
+	g_return_val_if_fail (comment, NULL);
+	g_return_val_if_fail (doc, NULL);
+
+	return xmlNewDocComment(cong_document_get_xml(doc), comment);
+}
+
+CongNodePtr
+cong_node_new_comment_len (const gchar *comment, 
+			   int len,	
+			   CongDocument *doc)
+{
+	gchar *tmp_comment;
+	CongNodePtr result;
+
+	g_return_val_if_fail (comment, NULL);
+	g_return_val_if_fail (doc, NULL);
+
+	/* There doesn't seem to be a xmlNewDocCommentLen function so we fake it: */
+	tmp_comment = g_strndup (comment, len);
+
+	result = xmlNewDocComment (cong_document_get_xml (doc), tmp_comment);
+
+	g_free (tmp_comment);
+
+	return result;
+}
+
+CongNodePtr
+cong_node_new_textual (CongNodeType textual_node_type,
+		       const gchar *content,
+		       CongDocument *doc)
+{
+	g_return_val_if_fail (cong_node_type_is_textual (textual_node_type), NULL);
+
+	switch (textual_node_type) {
+	default: g_assert_not_reached ();
+	case CONG_NODE_TYPE_TEXT:
+		return cong_node_new_text (content, doc);
+	case CONG_NODE_TYPE_CDATA_SECTION:
+		return cong_node_new_cdata_section (content, doc);
+	case CONG_NODE_TYPE_COMMENT:
+		return cong_node_new_comment (content, doc);
+	}
+}
+
+CongNodePtr
+cong_node_new_textual_len (CongNodeType textual_node_type,
+			   const gchar *content,
+			   int len,
+			   CongDocument *doc)
+{
+	g_return_val_if_fail (cong_node_type_is_textual (textual_node_type), NULL);
+
+	switch (textual_node_type) {
+	default: g_assert_not_reached ();
+	case CONG_NODE_TYPE_TEXT:
+		return cong_node_new_text_len (content, len, doc);
+	case CONG_NODE_TYPE_CDATA_SECTION:
+		return cong_node_new_cdata_section_len (content, len, doc);
+	case CONG_NODE_TYPE_COMMENT:
+		return cong_node_new_comment_len (content, len, doc);
+	}
+}
+
+
 /* Destruction: (the node has to have been unlinked from the tree already): */
 
-void cong_node_free(CongNodePtr node)
+/**
+ * cong_node_free:
+ * @node:
+ *
+ * TODO: Write me
+ */
+void 
+cong_node_free(CongNodePtr node)
 {
 	g_return_if_fail(node);
 
 	xmlFreeNode(node);
 }
 
+/**
+ * cong_node_generate_source:
+ * @node:  The node for which the XML source is to be generated
+ * 
+ * Generate XML source for the node 
+ *
+ * Returns: the XML source for the node as a UTF8 string.  The caller is responsible for freeing this with g_free
+ */
 gchar*
 cong_node_generate_source (CongNodePtr node)
 {
@@ -610,6 +1144,15 @@ cong_node_generate_source (CongNodePtr node)
 	return result;
 }
 
+/**
+ * cong_node_generate_child_source:
+ * @node:  The parent node
+ * 
+ * Generate XML source for the node's children, concatenated together as a UTF8 string.  Should handle entity references correctly.
+ * The result does not include the XML source for the node itself.
+ *
+ * Returns: the XML source for the node's children as a UTF8 string.  The caller is responsible for freeing this with g_free
+ */
 gchar*
 cong_node_generate_child_source (CongNodePtr node)
 {
@@ -656,7 +1199,14 @@ cong_node_generate_child_source (CongNodePtr node)
 	return result;	
 }
 
-
+/**
+ * cong_node_generate_source_from_byte_offset:
+ * @node:
+ * @byte_offset:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 gchar*
 cong_node_generate_source_from_byte_offset (CongNodePtr node,
 					    int start_byte_offset)
@@ -676,6 +1226,14 @@ cong_node_generate_source_from_byte_offset (CongNodePtr node,
 /* Generate XML source from TEXT and COMMENT nodes as a UTF8 string, up to the byte offset into the UTF-8: 
    FIXME: specify the end-point more precisely
  */
+/**
+ * cong_node_generate_source_up_to_byte_offset:
+ * @node:
+ * @byte_offset:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 gchar*
 cong_node_generate_source_up_to_byte_offset (CongNodePtr node,
 					     int end_byte_offset)
@@ -695,6 +1253,15 @@ cong_node_generate_source_up_to_byte_offset (CongNodePtr node,
 /* Generate XML source from TEXT and COMMENT nodes as a UTF8 string, between the given byte offset into the UTF-8: 
    FIXME: specify the end-point more precisely
  */
+/**
+ * cong_node_generate_source_between_byte_offsets:
+ * @node:
+ * @start_byte_offset:
+ * @end_byte_offset:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 gchar*
 cong_node_generate_source_between_byte_offsets (CongNodePtr node,
 						int start_byte_offset,
@@ -739,6 +1306,13 @@ cong_node_generate_source_between_byte_offsets (CongNodePtr node,
 	return result;
 }
 
+/**
+ * cong_node_recursive_set_doc:
+ * @node:
+ * @xml_doc:
+ *
+ * TODO: Write me
+ */
 void
 cong_node_recursive_set_doc(CongNodePtr node, xmlDocPtr xml_doc)
 {
@@ -751,7 +1325,15 @@ cong_node_recursive_set_doc(CongNodePtr node, xmlDocPtr xml_doc)
 	}
 }
 
-CongNodePtr cong_node_recursive_dup(CongNodePtr node)
+/**
+ * cong_node_recursive_dup:
+ * @node:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+CongNodePtr 
+cong_node_recursive_dup(CongNodePtr node)
 {
 	CongNodePtr new_node = xmlCopyNode(node, TRUE);
 
@@ -763,6 +1345,14 @@ CongNodePtr cong_node_recursive_dup(CongNodePtr node)
 	return new_node;
 }
 
+/**
+ * cong_node_is_descendant_of:
+ * @node:
+ * @potential_ancestor:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 gboolean
 cong_node_is_descendant_of (CongNodePtr node,
 			    CongNodePtr potential_ancestor)
@@ -827,7 +1417,14 @@ update_entities (CongNodePtr node)
 }
 
 /* Tree manipulation: */
-void cong_node_private_make_orphan(CongNodePtr node)
+/**
+ * cong_node_private_make_orphan:
+ * @node:
+ *
+ * TODO: Write me
+ */
+void 
+cong_node_private_make_orphan(CongNodePtr node)
 {
 	CongNodePtr former_parent;
 	CongNodePtr former_prev;
@@ -916,7 +1513,15 @@ void cong_node_private_make_orphan(CongNodePtr node)
 	}
 }
 
-void cong_node_private_add_after(CongNodePtr node, CongNodePtr older_sibling)
+/**
+ * cong_node_private_add_after:
+ * @node:
+ * @older_sibling:
+ *
+ * TODO: Write me
+ */
+void 
+cong_node_private_add_after(CongNodePtr node, CongNodePtr older_sibling)
 {
 	LOG_NODE_PRIVATE_MODIFICATION("cong_node_private_add_after");
 
@@ -971,7 +1576,15 @@ void cong_node_private_add_after(CongNodePtr node, CongNodePtr older_sibling)
 
 }
 
-void cong_node_private_add_before(CongNodePtr node, CongNodePtr younger_sibling)
+/**
+ * cong_node_private_add_before:
+ * @node:
+ * @younger_sibling:
+ *
+ * TODO: Write me
+ */
+void 
+cong_node_private_add_before(CongNodePtr node, CongNodePtr younger_sibling)
 {
 	LOG_NODE_PRIVATE_MODIFICATION("cong_node_private_add_before");
 
@@ -1027,7 +1640,16 @@ void cong_node_private_add_before(CongNodePtr node, CongNodePtr younger_sibling)
 
 }
 
-void cong_node_private_set_parent(CongNodePtr node, CongNodePtr adoptive_parent)
+/**
+ * cong_node_private_set_parent:
+ * @node:
+ * @adoptive_parent:
+ * @add_to_end:
+ *
+ * TODO: Write me
+ */
+void 
+cong_node_private_set_parent(CongNodePtr node, CongNodePtr adoptive_parent, gboolean add_to_end)
 {
 	LOG_NODE_PRIVATE_MODIFICATION("cong_node_private_set_parent");
 
@@ -1041,14 +1663,26 @@ void cong_node_private_set_parent(CongNodePtr node, CongNodePtr adoptive_parent)
 	cong_node_private_make_orphan(node);
 
 #if 1
-	if (adoptive_parent->last) {
-		cong_node_private_add_after(node, adoptive_parent->last);
+	if (add_to_end) {
+		if (adoptive_parent->last) {
+			cong_node_private_add_after(node, adoptive_parent->last);
+		} else {
+			g_assert(adoptive_parent->children == NULL);
+			
+			adoptive_parent->children = node;
+			adoptive_parent->last = node;
+			node->parent = adoptive_parent;
+		}
 	} else {
-		g_assert(adoptive_parent->children == NULL);
-
-		adoptive_parent->children = node;
-		adoptive_parent->last = node;
-		node->parent = adoptive_parent;
+		if (adoptive_parent->children) {
+			cong_node_private_add_before(node, adoptive_parent->children);
+		} else {
+			g_assert(adoptive_parent->last == NULL);
+			
+			adoptive_parent->children = node;
+			adoptive_parent->last = node;
+			node->parent = adoptive_parent;
+		}
 	}
 
 	update_entities (node);
@@ -1056,8 +1690,13 @@ void cong_node_private_set_parent(CongNodePtr node, CongNodePtr adoptive_parent)
 	/* Postconditions: */
 	{
 		g_assert(node->parent == adoptive_parent);
-		g_assert(adoptive_parent->last == node);
-		g_assert(node->next == NULL);
+		if (add_to_end) {
+			g_assert(adoptive_parent->last == node);
+			g_assert(node->next == NULL);
+		} else {
+			g_assert(adoptive_parent->children == node);
+			g_assert(node->prev == NULL);
+		}
 		CONG_NODE_SELF_TEST(node);
 		CONG_NODE_SELF_TEST(adoptive_parent);
 	}
@@ -1068,7 +1707,15 @@ void cong_node_private_set_parent(CongNodePtr node, CongNodePtr adoptive_parent)
 
 }
 
-void cong_node_private_set_text(CongNodePtr node, const xmlChar *new_content)
+/**
+ * cong_node_private_set_text:
+ * @node:
+ * @new_content:
+ *
+ * TODO: Write me
+ */
+void 
+cong_node_private_set_text(CongNodePtr node, const xmlChar *new_content)
 {
 	LOG_NODE_PRIVATE_MODIFICATION("cong_node_private_set_text");
 
@@ -1080,32 +1727,72 @@ void cong_node_private_set_text(CongNodePtr node, const xmlChar *new_content)
 	update_entities (node);
 }
 
-void cong_node_private_set_attribute(CongNodePtr node, const xmlChar *name, const xmlChar *value)
+/**
+ * cong_node_private_set_attribute:
+ * @node:
+ * @ns_ptr:
+ * @local_attribute_name:
+ * @value:
+ *
+ * TODO: Write me
+ */
+void 
+cong_node_private_set_attribute(CongNodePtr node,
+				xmlNs *ns_ptr, 
+				const xmlChar *local_attribute_name,
+				const xmlChar *value)
 {
 	LOG_NODE_PRIVATE_MODIFICATION("cong_node_private_set_attribute");
 
 	g_return_if_fail(node);
-	g_return_if_fail(name);
+	g_return_if_fail(local_attribute_name);
 	g_return_if_fail(value);
-
-	xmlSetProp(node, name, value);
+	
+	if(ns_ptr == NULL)
+		xmlSetProp(node, local_attribute_name, value);
+	else
+		xmlSetNsProp(node, ns_ptr, local_attribute_name, value);
 
 	update_entities (node);
 }
 
-void cong_node_private_remove_attribute(CongNodePtr node, const xmlChar *name)
+/**
+ * cong_node_private_remove_attribute:
+ * @node:
+ * @ns_ptr:
+ * @local_attribute_name:
+ *
+ * TODO: Write me
+ */
+void 
+cong_node_private_remove_attribute(CongNodePtr node, 
+				   xmlNs *ns_ptr,
+				   const xmlChar *local_attribute_name)
 {
 	LOG_NODE_PRIVATE_MODIFICATION("cong_node_private_remove_attribute");
 
 	g_return_if_fail(node);
-	g_return_if_fail(name);
+	g_return_if_fail(local_attribute_name);
 
-	xmlUnsetProp(node, name);
+	if(ns_ptr == NULL)
+		xmlUnsetProp(node, local_attribute_name);
+	else
+		xmlUnsetNsProp(node, ns_ptr, local_attribute_name);
 
 	update_entities (node);
 }
 
 /* Utilities: */
+/**
+ * cong_node_get_child_by_name:
+ * @node:  the parent node
+ * @ns_uri: URI of namespace to search for, or NULL
+ * @local_name: the local name within any namespace of the element to search for
+ *
+ * This function searches the children of @node looking for elements of the given name.
+ *
+ * Returns: the first child element matching the given name, or NULL if there are none
+ */
 CongNodePtr 
 cong_node_get_child_by_name (CongNodePtr node, 
 			     const gchar *ns_uri, 
@@ -1125,6 +1812,13 @@ cong_node_get_child_by_name (CongNodePtr node,
 	return NULL;
 }
 
+/**
+ * cong_node_get_first_text_node_descendant:
+ * @node:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 CongNodePtr 
 cong_node_get_first_text_node_descendant (CongNodePtr node)
 {
@@ -1147,13 +1841,21 @@ cong_node_get_first_text_node_descendant (CongNodePtr node)
 	}
 }
 
-enum CongWhitespaceHandling
+/**
+ * cong_node_get_whitespace_handling:
+ * @doc:
+ * @text_node:
+ *
+ * TODO: Write me
+ * Returns:
+ */
+CongWhitespaceHandling
 cong_node_get_whitespace_handling (CongDocument *doc,
 				   CongNodePtr text_node)
 {
 	g_return_val_if_fail (doc, CONG_WHITESPACE_NORMALIZE);
 	g_return_val_if_fail (text_node, CONG_WHITESPACE_NORMALIZE);
-	g_return_val_if_fail (cong_node_type (text_node)==CONG_NODE_TYPE_TEXT, CONG_WHITESPACE_NORMALIZE);
+	g_return_val_if_fail (cong_node_type_is_textual_content (cong_node_type (text_node)), CONG_WHITESPACE_NORMALIZE);
 
 	if (cong_node_type (text_node->parent)==CONG_NODE_TYPE_ELEMENT) {
 		CongDispspecElement *ds_element = cong_document_get_dispspec_element_for_node  (doc, text_node->parent);
@@ -1166,6 +1868,18 @@ cong_node_get_whitespace_handling (CongDocument *doc,
 	return CONG_WHITESPACE_NORMALIZE;
 }
 
+/**
+ * cong_node_should_be_visible_in_editor:
+ * @node:  a node to be tested
+ *
+ * The function determines if the node ought to be visible in the main editor view.
+ *
+ * As described in bug #123367, TEXT nodes that are either empty or purely whitespace
+ * should only appear in the main editor view if the DTD allows PCDATA at the location in the
+ * document.  Otherwise the text is probably merely formatting to prettify the source view. *
+ *
+ * Returns: a #gboolean which is TRUE iff the node ought to be visible in the main editor view
+ */
 gboolean
 cong_node_should_be_visible_in_editor (CongNodePtr node)
 {
@@ -1203,6 +1917,17 @@ cong_node_should_be_visible_in_editor (CongNodePtr node)
 	}
 }
 
+/**
+ * cong_node_is_valid_cursor_location:
+ * @node:  a node to be tested
+ *
+ * The function detemines if the node is a suitable location for the cursor.
+ *
+ * It currently only tests for TEXT nodes, but will eventually be expanded to
+ * allow COMMENT nodes as well.
+ *
+ * Returns: a #gboolean which is TRUE iff it is safe to put the cursor inside this node
+ */
 gboolean
 cong_node_is_valid_cursor_location (CongNodePtr node)
 {
@@ -1212,6 +1937,9 @@ cong_node_is_valid_cursor_location (CongNodePtr node)
 	default: return FALSE;
 	case XML_TEXT_NODE:
 		return cong_node_should_be_visible_in_editor (node);
+
+	case XML_CDATA_SECTION_NODE:
+		return TRUE;
 		
 	case XML_COMMENT_NODE:
 		/* Eventually allow comment editing: */		
@@ -1219,14 +1947,31 @@ cong_node_is_valid_cursor_location (CongNodePtr node)
 	}
 }
 
+/**
+ * cong_node_supports_byte_offsets:
+ * @node:  a node to be tested
+ *
+ * The function determines if #CongLocation objects that reference this node can have meaningful byte offsets
+ *
+ * Only TEXT, COMMENT and CDATA_SECTION nodes can currently have meaningful byte offsets.
+ * 
+ * Returns: a #gboolean which is TRUE if #CongLocations that reference this node can have a meaningful byte offset 
+ */
 gboolean
 cong_node_supports_byte_offsets (CongNodePtr node)
 {
 	g_return_val_if_fail (node, FALSE);
 	
-	return ((node->type == XML_TEXT_NODE)||(node->type == XML_COMMENT_NODE));
+	return cong_node_type_is_textual (node->type);
 }
 
+/**
+ * cong_node_can_be_cut:
+ * @node:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 gboolean
 cong_node_can_be_cut (CongNodePtr node)
 {
@@ -1253,6 +1998,13 @@ cong_node_can_be_cut (CongNodePtr node)
 	}
 }
 
+/**
+ * cong_node_can_be_copied:
+ * @node:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 gboolean
 cong_node_can_be_copied (CongNodePtr node)
 {
@@ -1260,6 +2012,14 @@ cong_node_can_be_copied (CongNodePtr node)
 	return cong_node_can_be_cut(node);
 }
 
+/**
+ * cong_node_get_deepest_common_parent:
+ * @n0:
+ * @n1:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 CongNodePtr 
 cong_node_get_deepest_common_parent (CongNodePtr n0, 
 				     CongNodePtr n1)
@@ -1281,6 +2041,16 @@ cong_node_get_deepest_common_parent (CongNodePtr n0,
 	return NULL;
 }
 
+/**
+ * cong_node_get_ordering:
+ * @n0:  first node to be compared
+ * @n1:  second node to be compared
+ *
+ * This functions compares the location of two nodes in the xml tree and returns a numeric comparsion representing
+ * their locations in a depth-first traversal.
+ *
+ * Returns: negative if n0 is reached before n1, zero if they are the same node, positive if n0 is reached after n1
+ */
 int 
 cong_node_get_ordering (CongNodePtr n0,
 			CongNodePtr n1)
@@ -1344,6 +2114,19 @@ cong_node_get_ordering (CongNodePtr n0,
 	}
 }
 
+/**
+ * cong_node_calc_first_node_in_subtree_satisfying:
+ * @node: the top of the subtree
+ * @predicate: the #CongNodePredicate to test nodes for
+ * @user_data: user-supplied data passed to the predicate
+ *
+ * Finds the first node in a depth-first traversal of the subtree below this node
+ * that satisfies the predicate.
+ *
+ * Note that @node is the initial node of the tree (and hence is tested first)
+ *
+ * Returns: the appropriate node satisfying @predicate, or NULL if there are none
+ */
 CongNodePtr
 cong_node_calc_first_node_in_subtree_satisfying (CongNodePtr node,
 						 CongNodePredicate predicate,
@@ -1374,6 +2157,19 @@ cong_node_calc_first_node_in_subtree_satisfying (CongNodePtr node,
 	return NULL;
 }
 
+/**
+ * cong_node_calc_final_node_in_subtree_satisfying:
+ * @node: the top of the subtree
+ * @predicate: the #CongNodePredicate to test nodes for
+ * @user_data: user-supplied data passed to the predicate
+ *
+ * Finds the final node in a depth-first traversal of the subtree below this node
+ * that satisfies the predicate.
+ *
+ * Note that @node is the initial node of the tree (and hence is tested last)
+ *
+ * Returns: the appropriate node satisfying @predicate, or NULL if there are none
+ */
 CongNodePtr
 cong_node_calc_final_node_in_subtree_satisfying (CongNodePtr node, 
 						 CongNodePredicate predicate,
@@ -1404,6 +2200,17 @@ cong_node_calc_final_node_in_subtree_satisfying (CongNodePtr node,
 	}
 }
 
+/**
+ * cong_node_calc_prev_node_satisfying:
+ * @node: the start of the search
+ * @predicate: the #CongNodePredicate to test nodes for
+ * @user_data: user-supplied data passed to the predicate
+ *
+ * Finds the first preceding node relative to the input that satisfies the predicate,
+ * in an imagined depth-first traversal of the document.  Includes ancestors.
+ *
+ * Returns: the appropriate node satisfying @predicate, or NULL if there are none
+ */
 CongNodePtr
 cong_node_calc_prev_node_satisfying (CongNodePtr node, 
 				     CongNodePredicate predicate,
@@ -1441,6 +2248,17 @@ cong_node_calc_prev_node_satisfying (CongNodePtr node,
 	}
 }
 
+/**
+ * cong_node_calc_next_node_satisfying:
+ * @node: the start of the search
+ * @predicate: the #CongNodePredicate to test nodes for
+ * @user_data: user-supplied data passed to the predicate
+ *
+ * Finds the first following node relative to the input that satisfies the predicate,
+ * in an imagined depth-first traversal of the document.   Includes ancestors.
+ *
+ * Returns: the appropriate node satisfying @predicate, or NULL if there are none
+ */
 CongNodePtr
 cong_node_calc_next_node_satisfying (CongNodePtr node,
 				     CongNodePredicate predicate,
@@ -1475,7 +2293,3 @@ cong_node_calc_next_node_satisfying (CongNodePtr node,
 		return NULL;
 	}
 }
-
-
-/* Internal function definitions: */
-
