@@ -151,7 +151,7 @@ xmlDocPtr cong_ui_transform_doc(CongDocument *doc,
 gboolean cong_ui_transform_doc_to_uri(CongDocument *doc,
 				      const gchar *stylesheet_filename,
 				      GList *list_of_parameters,
-				      const gchar *uri,
+				      const gchar *string_uri,
 				      GtkWindow *toplevel_window);
 
 gboolean cong_ui_load_imported_file_content(const gchar *uri,
