@@ -26,6 +26,13 @@
 #include "cong-view.h"
 #include "cong-document.h"
 
+/**
+ * cong_view_get_document:
+ * @view:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 CongDocument*
 cong_view_get_document(CongView *view)
 {
@@ -34,10 +41,17 @@ cong_view_get_document(CongView *view)
 	return view->doc;
 }
 
+/**
+ * cong_view_get_default_dispspec
+ * @view:
+ *
+ * TODO: Write me
+ * Returns:
+ */
 CongDispspec*
-cong_view_get_dispspec(CongView *view)
+cong_view_get_default_dispspec(CongView *view)
 {
 	g_return_val_if_fail(view, NULL);
 
-	return cong_document_get_dispspec(view->doc);
+	return cong_document_get_default_dispspec (view->doc);
 }
