@@ -41,12 +41,6 @@ G_BEGIN_DECLS
 #define RELEASE 1
 #undef WINDOWS_BUILD
 
-#ifdef WINDOWS_BUILD
-# define isblank(c) ((c) == ' ' || (c) == '\n' || (c) == '\r' || (c) == '\t')
-#endif
-
-#define NEW_LOOK 1
-
 #if ENABLE_PRINTING
 #include <libgnomeprint/gnome-print.h>
 #include <libgnomeprint/gnome-print-job.h>
@@ -122,26 +116,6 @@ struct CongElementDescription
 	gchar *local_name;
 };
 
-typedef struct CongStylesheetParameter CongStylesheetParameter;
-struct CongStylesheetParameter
-{
-	gchar *name;
-	gchar *value;
-};
-
-CongStylesheetParameter*
-cong_stylesheet_parameter_new (const gchar *name,
-			       const gchar *value);
-
-void
-cong_stylesheet_parameter_free (CongStylesheetParameter *parameter);
-
-void
-cong_stylesheet_parameter_list_free (GList *list_of_parameters);
-
-void
-cong_stylesheet_parameter_list_debug (GList *list_of_parameters);
-
 CongEditorView *cong_editor_view_new(CongDocument *doc);
 void cong_editor_view_free(CongEditorView *editor_view);
 GtkWidget* cong_editor_view_get_widget(CongEditorView *editor_view);
