@@ -13,6 +13,14 @@
 #include <libxml/tree.h>
 #include "gxx-object-to-xml-tree.h"
 
+/**
+ * gxx_hash_table_of_children_with_pcdata_to_xml_tree:
+ * @key:
+ * @value:
+ * @user_data:
+ *
+ * TODO: Write me
+ */
 void
 gxx_hash_table_of_children_with_pcdata_to_xml_tree (gpointer key,
 						    gpointer value,
@@ -20,10 +28,10 @@ gxx_hash_table_of_children_with_pcdata_to_xml_tree (gpointer key,
 {
 	GXXCallbackData_HashTableOfChildrenWithPCDATA *cb_data = (GXXCallbackData_HashTableOfChildrenWithPCDATA *)user_data;
 	xmlNodePtr child_node;
-	xmlNsPtr ns;
 
-	g_assert (key);
-	g_assert (g_utf8_validate (key, -1, NULL));
+	if (key) {
+		g_assert (g_utf8_validate (key, -1, NULL));
+	}
 	g_assert (value);
 	g_assert (g_utf8_validate (value, -1, NULL));
 
@@ -39,14 +47,18 @@ gxx_hash_table_of_children_with_pcdata_to_xml_tree (gpointer key,
 	xmlAddChild (cb_data->xml_node, 
 		     child_node);    
 
-	ns = xmlSearchNsByHref (cb_data->xml_node->doc, 
-				child_node, 
-				cb_data->str_hashing_attribute_ns_uri);
-	if (ns == NULL) {
-		g_warning ("FIXME couldn't find namespace %s ", cb_data->str_hashing_attribute_ns_uri);
+	if (key) {
+		xmlNsPtr ns;
+
+		ns = xmlSearchNsByHref (cb_data->xml_node->doc, 
+					child_node, 
+					cb_data->str_hashing_attribute_ns_uri);
+		if (ns == NULL) {
+			g_warning ("FIXME couldn't find namespace %s ", cb_data->str_hashing_attribute_ns_uri);
+		}
+		xmlSetNsProp (child_node,
+			      ns,
+			      cb_data->str_hashing_attribute_name, 
+			      key);
 	}
-	xmlSetNsProp (child_node,
-		      ns,
-		      cb_data->str_hashing_attribute_name, 
-		      key);
 }
