@@ -346,7 +346,7 @@ random_text (RandomCreationInfo *rci)
 		return g_strdup ("the quick brown fox jumps over the lazy dog");
 
 	case 1:
-		return g_strdup ("lore ipsum");
+		return g_strdup ("Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.");
 
 	case 2:
 		/* Generate an entirely random unicode string: */
